Method: Aws::DocDB::Types::DBInstanceStatusInfo#normal
- Defined in:
- lib/aws-sdk-docdb/types.rb
#normal ⇒ Boolean
A Boolean value that is true if the instance is operating normally, or false if the instance is in an error state.
2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/aws-sdk-docdb/types.rb', line 2251 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |