Class: Aws::DocDB::Types::ApplyPendingMaintenanceActionMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::ApplyPendingMaintenanceActionMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass ApplyPendingMaintenanceActionMessage data as a hash:
{
resource_identifier: "String", # required
apply_action: "String", # required
opt_in_type: "String", # required
}
Represents the input to ApplyPendingMaintenanceAction.
Instance Attribute Summary collapse
-
#apply_action ⇒ String
The pending maintenance action to apply to this resource.
-
#opt_in_type ⇒ String
A value that specifies the type of opt-in request or undoes an opt-in request.
-
#resource_identifier ⇒ String
The Amazon Resource Name (ARN) of the resource that the pending maintenance action applies to.
Instance Attribute Details
#apply_action ⇒ String
The pending maintenance action to apply to this resource.
Valid values: system-update, db-upgrade
83 84 85 86 87 88 |
# File 'lib/aws-sdk-docdb/types.rb', line 83 class ApplyPendingMaintenanceActionMessage < Struct.new( :resource_identifier, :apply_action, :opt_in_type) include Aws::Structure end |
#opt_in_type ⇒ String
A value that specifies the type of opt-in request or undoes an opt-in request. An opt-in request of type immediate can’t be undone.
Valid values:
-
immediate- Apply the maintenance action immediately. -
next-maintenance- Apply the maintenance action during the next maintenance window for the resource. -
undo-opt-in- Cancel any existingnext-maintenanceopt-in requests.
83 84 85 86 87 88 |
# File 'lib/aws-sdk-docdb/types.rb', line 83 class ApplyPendingMaintenanceActionMessage < Struct.new( :resource_identifier, :apply_action, :opt_in_type) include Aws::Structure end |
#resource_identifier ⇒ String
The Amazon Resource Name (ARN) of the resource that the pending maintenance action applies to.
83 84 85 86 87 88 |
# File 'lib/aws-sdk-docdb/types.rb', line 83 class ApplyPendingMaintenanceActionMessage < Struct.new( :resource_identifier, :apply_action, :opt_in_type) include Aws::Structure end |