Class: Aws::DocDB::Types::CreateDBClusterMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::CreateDBClusterMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass CreateDBClusterMessage data as a hash:
{
availability_zones: ["String"],
backup_retention_period: 1,
db_cluster_identifier: "String", # required
db_cluster_parameter_group_name: "String",
vpc_security_group_ids: ["String"],
db_subnet_group_name: "String",
engine: "String", # required
engine_version: "String",
port: 1,
master_username: "String", # required
master_user_password: "String", # required
preferred_backup_window: "String",
preferred_maintenance_window: "String",
tags: [
{
key: "String",
value: "String",
},
],
storage_encrypted: false,
kms_key_id: "String",
enable_cloudwatch_logs_exports: ["String"],
deletion_protection: false,
}
Represents the input to CreateDBCluster.
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<String>
A list of Amazon EC2 Availability Zones that instances in the DB cluster can be created in.
-
#backup_retention_period ⇒ Integer
The number of days for which automated backups are retained.
-
#db_cluster_identifier ⇒ String
The DB cluster identifier.
-
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group to associate with this DB cluster.
-
#db_subnet_group_name ⇒ String
A DB subnet group to associate with this DB cluster.
-
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted.
-
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that need to be enabled for exporting to Amazon CloudWatch Logs.
-
#engine ⇒ String
The name of the database engine to be used for this DB cluster.
-
#engine_version ⇒ String
The version number of the database engine to use.
-
#kms_key_id ⇒ String
The AWS KMS key identifier for an encrypted DB cluster.
-
#master_user_password ⇒ String
The password for the master database user.
-
#master_username ⇒ String
The name of the master user for the DB cluster.
-
#port ⇒ Integer
The port number on which the instances in the DB cluster accept connections.
-
#preferred_backup_window ⇒ String
The daily time range during which automated backups are created if automated backups are enabled using the
BackupRetentionPeriodparameter. -
#preferred_maintenance_window ⇒ String
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
-
#storage_encrypted ⇒ Boolean
Specifies whether the DB cluster is encrypted.
-
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the DB cluster.
-
#vpc_security_group_ids ⇒ Array<String>
A list of EC2 VPC security groups to associate with this DB cluster.
Instance Attribute Details
#availability_zones ⇒ Array<String>
A list of Amazon EC2 Availability Zones that instances in the DB cluster can be created in.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#backup_retention_period ⇒ Integer
The number of days for which automated backups are retained. You must specify a minimum value of 1.
Default: 1
Constraints:
-
Must be a value from 1 to 35.
^
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_cluster_identifier ⇒ String
The DB cluster identifier. This parameter is stored as a lowercase string.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens.
-
The first character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
Example: my-cluster
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group to associate with this DB cluster.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_subnet_group_name ⇒ String
A DB subnet group to associate with this DB cluster.
Constraints: Must match the name of an existing DBSubnetGroup. Must not be default.
Example: mySubnetgroup
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted. If DeletionProtection is enabled, the cluster cannot be deleted unless it is modified and DeletionProtection is disabled. DeletionProtection protects clusters from being accidentally deleted.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that need to be enabled for exporting to Amazon CloudWatch Logs.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#engine ⇒ String
The name of the database engine to be used for this DB cluster.
Valid values: docdb
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#engine_version ⇒ String
The version number of the database engine to use.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#kms_key_id ⇒ String
The AWS KMS key identifier for an encrypted DB cluster.
The AWS KMS key identifier is the Amazon Resource Name (ARN) for the AWS KMS encryption key. If you are creating a DB cluster using the same AWS account that owns the AWS KMS encryption key that is used to encrypt the new DB cluster, you can use the AWS KMS key alias instead of the ARN for the AWS KMS encryption key.
If an encryption key is not specified in KmsKeyId:
-
If
ReplicationSourceIdentifieridentifies an encrypted source, then Amazon DocumentDB uses the encryption key that is used to encrypt the source. Otherwise, Amazon DocumentDB uses your default encryption key. -
If the
StorageEncryptedparameter istrueandReplicationSourceIdentifieris not specified, Amazon DocumentDB uses your default encryption key.
AWS KMS creates the default encryption key for your AWS account. Your AWS account has a different default encryption key for each AWS Region.
If you create a replica of an encrypted DB cluster in another AWS Region, you must set KmsKeyId to a KMS key ID that is valid in the destination AWS Region. This key is used to encrypt the replica in that AWS Region.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#master_user_password ⇒ String
The password for the master database user. This password can contain any printable ASCII character except forward slash (/), double quote (“), or the ”at“ symbol (@).
Constraints: Must contain from 8 to 41 characters.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#master_username ⇒ String
The name of the master user for the DB cluster.
Constraints:
-
Must be from 1 to 16 letters or numbers.
-
The first character must be a letter.
-
Cannot be a reserved word for the chosen database engine.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#port ⇒ Integer
The port number on which the instances in the DB cluster accept connections.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#preferred_backup_window ⇒ String
The daily time range during which automated backups are created if automated backups are enabled using the BackupRetentionPeriod parameter.
The default is a 30-minute window selected at random from an 8-hour block of time for each AWS Region.
Constraints:
-
Must be in the format
hh24:mi-hh24:mi. -
Must be in Universal Coordinated Time (UTC).
-
Must not conflict with the preferred maintenance window.
-
Must be at least 30 minutes.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#preferred_maintenance_window ⇒ String
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
Format: ddd:hh24:mi-ddd:hh24:mi
The default is a 30-minute window selected at random from an 8-hour block of time for each AWS Region, occurring on a random day of the week.
Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun
Constraints: Minimum 30-minute window.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#storage_encrypted ⇒ Boolean
Specifies whether the DB cluster is encrypted.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the DB cluster.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of EC2 VPC security groups to associate with this DB cluster.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-docdb/types.rb', line 573 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :preferred_backup_window, :preferred_maintenance_window, :tags, :storage_encrypted, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |