Class: Aws::DocDB::Types::CreateDBInstanceMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::CreateDBInstanceMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass CreateDBInstanceMessage data as a hash:
{
db_instance_identifier: "String", # required
db_instance_class: "String", # required
engine: "String", # required
availability_zone: "String",
preferred_maintenance_window: "String",
auto_minor_version_upgrade: false,
tags: [
{
key: "String",
value: "String",
},
],
db_cluster_identifier: "String", # required
promotion_tier: 1,
}
Represents the input to CreateDBInstance.
Instance Attribute Summary collapse
-
#auto_minor_version_upgrade ⇒ Boolean
Indicates that minor engine upgrades are applied automatically to the DB instance during the maintenance window.
-
#availability_zone ⇒ String
The Amazon EC2 Availability Zone that the DB instance is created in.
-
#db_cluster_identifier ⇒ String
The identifier of the DB cluster that the instance will belong to.
-
#db_instance_class ⇒ String
The compute and memory capacity of the DB instance; for example,
db.r5.large. -
#db_instance_identifier ⇒ String
The DB instance identifier.
-
#engine ⇒ String
The name of the database engine to be used for this instance.
-
#preferred_maintenance_window ⇒ String
The time range each week during which system maintenance can occur, in Universal Coordinated Time (UTC).
-
#promotion_tier ⇒ Integer
A value that specifies the order in which an Amazon DocumentDB replica is promoted to the primary instance after a failure of the existing primary instance.
-
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the DB instance.
Instance Attribute Details
#auto_minor_version_upgrade ⇒ Boolean
Indicates that minor engine upgrades are applied automatically to the DB instance during the maintenance window.
Default: true
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |
#availability_zone ⇒ String
The Amazon EC2 Availability Zone that the DB instance is created in.
Default: A random, system-chosen Availability Zone in the endpoint’s AWS Region.
Example: us-east-1d
Constraint: The AvailabilityZone parameter can’t be specified if the MultiAZ parameter is set to true. The specified Availability Zone must be in the same AWS Region as the current endpoint.
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |
#db_cluster_identifier ⇒ String
The identifier of the DB cluster that the instance will belong to.
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |
#db_instance_class ⇒ String
The compute and memory capacity of the DB instance; for example, db.r5.large.
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |
#db_instance_identifier ⇒ String
The DB instance identifier. This parameter is stored as a lowercase string.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens.
-
The first character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
Example: mydbinstance
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |
#engine ⇒ String
The name of the database engine to be used for this instance.
Valid value: docdb
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |
#preferred_maintenance_window ⇒ String
The time range each week during which system maintenance can occur, in Universal Coordinated Time (UTC).
Format: ddd:hh24:mi-ddd:hh24:mi
The default is a 30-minute window selected at random from an 8-hour block of time for each AWS Region, occurring on a random day of the week.
Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun
Constraints: Minimum 30-minute window.
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |
#promotion_tier ⇒ Integer
A value that specifies the order in which an Amazon DocumentDB replica is promoted to the primary instance after a failure of the existing primary instance.
Default: 1
Valid values: 0-15
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the DB instance.
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-docdb/types.rb', line 841 class CreateDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :engine, :availability_zone, :preferred_maintenance_window, :auto_minor_version_upgrade, :tags, :db_cluster_identifier, :promotion_tier) include Aws::Structure end |