Class: Aws::DocDB::Types::CreateEventSubscriptionMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::CreateEventSubscriptionMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Represents the input to CreateEventSubscription.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
A Boolean value; set to
trueto activate the subscription, set tofalseto create the subscription but not active it. -
#event_categories ⇒ Array<String>
A list of event categories for a
SourceTypethat you want to subscribe to. -
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the SNS topic created for event notification.
-
#source_ids ⇒ Array<String>
The list of identifiers of the event sources for which events are returned.
-
#source_type ⇒ String
The type of source that is generating the events.
-
#subscription_name ⇒ String
The name of the subscription.
-
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the event subscription.
Instance Attribute Details
#enabled ⇒ Boolean
A Boolean value; set to true to activate the subscription, set to false to create the subscription but not active it.
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-docdb/types.rb', line 1184 class CreateEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :event_categories, :source_ids, :enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#event_categories ⇒ Array<String>
A list of event categories for a SourceType that you want to subscribe to.
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-docdb/types.rb', line 1184 class CreateEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :event_categories, :source_ids, :enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the SNS topic created for event notification. Amazon SNS creates the ARN when you create a topic and subscribe to it.
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-docdb/types.rb', line 1184 class CreateEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :event_categories, :source_ids, :enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#source_ids ⇒ Array<String>
The list of identifiers of the event sources for which events are returned. If not specified, then all sources are included in the response. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can’t end with a hyphen or contain two consecutive hyphens.
Constraints:
-
If
SourceIdsare provided,SourceTypemust also be provided. -
If the source type is an instance, a
DBInstanceIdentifiermust be provided. -
If the source type is a security group, a
DBSecurityGroupNamemust be provided. -
If the source type is a parameter group, a
DBParameterGroupNamemust be provided. -
If the source type is a snapshot, a
DBSnapshotIdentifiermust be provided.
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-docdb/types.rb', line 1184 class CreateEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :event_categories, :source_ids, :enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of source that is generating the events. For example, if you want to be notified of events generated by an instance, you would set this parameter to db-instance. If this value is not specified, all events are returned.
Valid values: db-instance, db-cluster, db-parameter-group, db-security-group, db-cluster-snapshot
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-docdb/types.rb', line 1184 class CreateEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :event_categories, :source_ids, :enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#subscription_name ⇒ String
The name of the subscription.
Constraints: The name must be fewer than 255 characters.
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-docdb/types.rb', line 1184 class CreateEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :event_categories, :source_ids, :enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the event subscription.
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-docdb/types.rb', line 1184 class CreateEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :event_categories, :source_ids, :enabled, :tags) SENSITIVE = [] include Aws::Structure end |