Class: Aws::DocDB::Types::DBCluster
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBCluster
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Detailed information about a DB cluster.
Instance Attribute Summary collapse
-
#associated_roles ⇒ Array<Types::DBClusterRole>
Provides a list of the AWS Identity and Access Management (IAM) roles that are associated with the DB cluster.
-
#availability_zones ⇒ Array<String>
Provides the list of Amazon EC2 Availability Zones that instances in the DB cluster can be created in.
-
#backup_retention_period ⇒ Integer
Specifies the number of days for which automatic DB snapshots are retained.
-
#cluster_create_time ⇒ Time
Specifies the time when the DB cluster was created, in Universal Coordinated Time (UTC).
-
#db_cluster_arn ⇒ String
The Amazon Resource Name (ARN) for the DB cluster.
-
#db_cluster_identifier ⇒ String
Contains a user-supplied DB cluster identifier.
-
#db_cluster_members ⇒ Array<Types::DBClusterMember>
Provides the list of instances that make up the DB cluster.
-
#db_cluster_parameter_group ⇒ String
Specifies the name of the DB cluster parameter group for the DB cluster.
-
#db_cluster_resource_id ⇒ String
The AWS Region-unique, immutable identifier for the DB cluster.
-
#db_subnet_group ⇒ String
Specifies information on the subnet group that is associated with the DB cluster, including the name, description, and subnets in the subnet group.
-
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted.
-
#earliest_restorable_time ⇒ Time
The earliest time to which a database can be restored with point-in-time restore.
-
#enabled_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that this DB cluster is configured to export to Amazon CloudWatch Logs.
-
#endpoint ⇒ String
Specifies the connection endpoint for the primary instance of the DB cluster.
-
#engine ⇒ String
Provides the name of the database engine to be used for this DB cluster.
-
#engine_version ⇒ String
Indicates the database engine version.
-
#hosted_zone_id ⇒ String
Specifies the ID that Amazon Route 53 assigns when you create a hosted zone.
-
#kms_key_id ⇒ String
If
StorageEncryptedistrue, the AWS KMS key identifier for the encrypted DB cluster. -
#latest_restorable_time ⇒ Time
Specifies the latest time to which a database can be restored with point-in-time restore.
-
#master_username ⇒ String
Contains the master user name for the DB cluster.
-
#multi_az ⇒ Boolean
Specifies whether the DB cluster has instances in multiple Availability Zones.
-
#percent_progress ⇒ String
Specifies the progress of the operation as a percentage.
-
#port ⇒ Integer
Specifies the port that the database engine is listening on.
-
#preferred_backup_window ⇒ String
Specifies the daily time range during which automated backups are created if automated backups are enabled, as determined by the
BackupRetentionPeriod. -
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
-
#reader_endpoint ⇒ String
The reader endpoint for the DB cluster.
-
#status ⇒ String
Specifies the current state of this DB cluster.
-
#storage_encrypted ⇒ Boolean
Specifies whether the DB cluster is encrypted.
-
#vpc_security_groups ⇒ Array<Types::VpcSecurityGroupMembership>
Provides a list of virtual private cloud (VPC) security groups that the DB cluster belongs to.
Instance Attribute Details
#associated_roles ⇒ Array<Types::DBClusterRole>
Provides a list of the AWS Identity and Access Management (IAM) roles that are associated with the DB cluster. IAM roles that are associated with a DB cluster grant permission for the DB cluster to access other AWS services on your behalf.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#availability_zones ⇒ Array<String>
Provides the list of Amazon EC2 Availability Zones that instances in the DB cluster can be created in.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#backup_retention_period ⇒ Integer
Specifies the number of days for which automatic DB snapshots are retained.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#cluster_create_time ⇒ Time
Specifies the time when the DB cluster was created, in Universal Coordinated Time (UTC).
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_cluster_arn ⇒ String
The Amazon Resource Name (ARN) for the DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_cluster_identifier ⇒ String
Contains a user-supplied DB cluster identifier. This identifier is the unique key that identifies a DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_cluster_members ⇒ Array<Types::DBClusterMember>
Provides the list of instances that make up the DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_cluster_parameter_group ⇒ String
Specifies the name of the DB cluster parameter group for the DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_cluster_resource_id ⇒ String
The AWS Region-unique, immutable identifier for the DB cluster. This identifier is found in AWS CloudTrail log entries whenever the AWS KMS key for the DB cluster is accessed.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_subnet_group ⇒ String
Specifies information on the subnet group that is associated with the DB cluster, including the name, description, and subnets in the subnet group.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted. If DeletionProtection is enabled, the cluster cannot be deleted unless it is modified and DeletionProtection is disabled. DeletionProtection protects clusters from being accidentally deleted.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#earliest_restorable_time ⇒ Time
The earliest time to which a database can be restored with point-in-time restore.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#enabled_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that this DB cluster is configured to export to Amazon CloudWatch Logs.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#endpoint ⇒ String
Specifies the connection endpoint for the primary instance of the DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#engine ⇒ String
Provides the name of the database engine to be used for this DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#engine_version ⇒ String
Indicates the database engine version.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#hosted_zone_id ⇒ String
Specifies the ID that Amazon Route 53 assigns when you create a hosted zone.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#kms_key_id ⇒ String
If StorageEncrypted is true, the AWS KMS key identifier for the encrypted DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#latest_restorable_time ⇒ Time
Specifies the latest time to which a database can be restored with point-in-time restore.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#master_username ⇒ String
Contains the master user name for the DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#multi_az ⇒ Boolean
Specifies whether the DB cluster has instances in multiple Availability Zones.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#percent_progress ⇒ String
Specifies the progress of the operation as a percentage.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#port ⇒ Integer
Specifies the port that the database engine is listening on.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#preferred_backup_window ⇒ String
Specifies the daily time range during which automated backups are created if automated backups are enabled, as determined by the BackupRetentionPeriod.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#reader_endpoint ⇒ String
The reader endpoint for the DB cluster. The reader endpoint for a DB cluster load balances connections across the Amazon DocumentDB replicas that are available in a DB cluster. As clients request new connections to the reader endpoint, Amazon DocumentDB distributes the connection requests among the Amazon DocumentDB replicas in the DB cluster. This functionality can help balance your read workload across multiple Amazon DocumentDB replicas in your DB cluster.
If a failover occurs, and the Amazon DocumentDB replica that you are connected to is promoted to be the primary instance, your connection is dropped. To continue sending your read workload to other Amazon DocumentDB replicas in the cluster, you can then reconnect to the reader endpoint.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#status ⇒ String
Specifies the current state of this DB cluster.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#storage_encrypted ⇒ Boolean
Specifies whether the DB cluster is encrypted.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#vpc_security_groups ⇒ Array<Types::VpcSecurityGroupMembership>
Provides a list of virtual private cloud (VPC) security groups that the DB cluster belongs to.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-docdb/types.rb', line 1085 class DBCluster < Struct.new( :availability_zones, :backup_retention_period, :db_cluster_identifier, :db_cluster_parameter_group, :db_subnet_group, :status, :percent_progress, :earliest_restorable_time, :endpoint, :reader_endpoint, :multi_az, :engine, :engine_version, :latest_restorable_time, :port, :master_username, :preferred_backup_window, :preferred_maintenance_window, :db_cluster_members, :vpc_security_groups, :hosted_zone_id, :storage_encrypted, :kms_key_id, :db_cluster_resource_id, :db_cluster_arn, :associated_roles, :cluster_create_time, :enabled_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |