Class: Aws::DocDB::Types::DBClusterMember
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBClusterMember
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Contains information about an instance that is part of a DB cluster.
Instance Attribute Summary collapse
-
#db_cluster_parameter_group_status ⇒ String
Specifies the status of the DB cluster parameter group for this member of the DB cluster.
-
#db_instance_identifier ⇒ String
Specifies the instance identifier for this member of the DB cluster.
-
#is_cluster_writer ⇒ Boolean
A value that is
trueif the cluster member is the primary instance for the DB cluster andfalseotherwise. -
#promotion_tier ⇒ Integer
A value that specifies the order in which an Amazon DocumentDB replica is promoted to the primary instance after a failure of the existing primary instance.
Instance Attribute Details
#db_cluster_parameter_group_status ⇒ String
Specifies the status of the DB cluster parameter group for this member of the DB cluster.
1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/aws-sdk-docdb/types.rb', line 1142 class DBClusterMember < Struct.new( :db_instance_identifier, :is_cluster_writer, :db_cluster_parameter_group_status, :promotion_tier) include Aws::Structure end |
#db_instance_identifier ⇒ String
Specifies the instance identifier for this member of the DB cluster.
1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/aws-sdk-docdb/types.rb', line 1142 class DBClusterMember < Struct.new( :db_instance_identifier, :is_cluster_writer, :db_cluster_parameter_group_status, :promotion_tier) include Aws::Structure end |
#is_cluster_writer ⇒ Boolean
A value that is true if the cluster member is the primary instance for the DB cluster and false otherwise.
1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/aws-sdk-docdb/types.rb', line 1142 class DBClusterMember < Struct.new( :db_instance_identifier, :is_cluster_writer, :db_cluster_parameter_group_status, :promotion_tier) include Aws::Structure end |
#promotion_tier ⇒ Integer
A value that specifies the order in which an Amazon DocumentDB replica is promoted to the primary instance after a failure of the existing primary instance.
1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/aws-sdk-docdb/types.rb', line 1142 class DBClusterMember < Struct.new( :db_instance_identifier, :is_cluster_writer, :db_cluster_parameter_group_status, :promotion_tier) include Aws::Structure end |