Class: Aws::DocDB::Types::DBClusterRole
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBClusterRole
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Describes an Identity and Access Management (IAM) role that is associated with a cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAMrole that is associated with the DB cluster.
-
#status ⇒ String
Describes the state of association between the IAMrole and the cluster.
Instance Attribute Details
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAMrole that is associated with the DB cluster.
1769 1770 1771 1772 1773 1774 |
# File 'lib/aws-sdk-docdb/types.rb', line 1769 class DBClusterRole < Struct.new( :role_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Describes the state of association between the IAMrole and the
cluster. The Status property returns one of the following values:
-
ACTIVE- The IAMrole ARN is associated with the cluster and can be used to access other Amazon Web Services services on your behalf. -
PENDING- The IAMrole ARN is being associated with the cluster. -
INVALID- The IAMrole ARN is associated with the cluster, but the cluster cannot assume the IAMrole to access other Amazon Web Services services on your behalf.
1769 1770 1771 1772 1773 1774 |
# File 'lib/aws-sdk-docdb/types.rb', line 1769 class DBClusterRole < Struct.new( :role_arn, :status) SENSITIVE = [] include Aws::Structure end |