Class: Aws::DocDB::Types::DBClusterSnapshot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Detailed information about a cluster snapshot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zonesArray<String>

Provides the list of Amazon EC2 Availability Zones that instances in the cluster snapshot can be restored in.

Returns:

  • (Array<String>)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_create_timeTime

Specifies the time when the cluster was created, in Universal Coordinated Time (UTC).

Returns:

  • (Time)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_identifierString

Specifies the cluster identifier of the cluster that this cluster snapshot was created from.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_snapshot_arnString

The Amazon Resource Name (ARN) for the cluster snapshot.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_snapshot_identifierString

Specifies the identifier for the cluster snapshot.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

Specifies the name of the database engine.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

Provides the version of the database engine for this cluster snapshot.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

If StorageEncrypted is true, the KMS key identifier for the encrypted cluster snapshot.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#master_usernameString

Provides the master user name for the cluster snapshot.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#percent_progressInteger

Specifies the percentage of the estimated data that has been transferred.

Returns:

  • (Integer)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

Specifies the port that the cluster was listening on at the time of the snapshot.

Returns:

  • (Integer)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_create_timeTime

Provides the time when the snapshot was taken, in UTC.

Returns:

  • (Time)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_typeString

Provides the type of the cluster snapshot.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_db_cluster_snapshot_arnString

If the cluster snapshot was copied from a source cluster snapshot, the ARN for the source cluster snapshot; otherwise, a null value.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Specifies the status of this cluster snapshot.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_encryptedBoolean

Specifies whether the cluster snapshot is encrypted.

Returns:

  • (Boolean)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

Storage type associated with your cluster snapshot

For information on storage types for Amazon DocumentDB clusters, see Cluster storage configurations in the Amazon DocumentDB Developer Guide.

Valid values for storage type - standard | iopt1

Default value is standard

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

Provides the virtual private cloud (VPC) ID that is associated with the cluster snapshot.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-docdb/types.rb', line 1869

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end