Class: Aws::DocDB::Types::DBEngineVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBEngineVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Detailed information about an engine version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_engine_description ⇒ String
The description of the database engine.
-
#db_engine_version_description ⇒ String
The description of the database engine version.
-
#db_parameter_group_family ⇒ String
The name of the parameter group family for the database engine.
-
#engine ⇒ String
The name of the database engine.
-
#engine_version ⇒ String
The version number of the database engine.
-
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to Amazon CloudWatch Logs.
-
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Amazon DocumentDB Serverless properties or limits that differ between Amazon DocumentDB engine versions.
-
#supported_ca_certificate_identifiers ⇒ Array<String>
A list of the supported CA certificate identifiers.
-
#supports_certificate_rotation_without_restart ⇒ Boolean
Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.
-
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
A value that indicates whether the engine version supports exporting the log types specified by
ExportableLogTypesto CloudWatch Logs. -
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
Instance Attribute Details
#db_engine_description ⇒ String
The description of the database engine.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#db_engine_version_description ⇒ String
The description of the database engine version.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_family ⇒ String
The name of the parameter group family for the database engine.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the database engine.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version number of the database engine.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to Amazon CloudWatch Logs.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Amazon DocumentDB Serverless properties or limits that differ between Amazon DocumentDB engine versions. You can test the values of this attribute when deciding which Amazon DocumentDB version to use in a new or upgraded cluster. You can also retrieve the version of an existing cluster and check whether that version supports certain Amazon DocumentDB Serverless features before you attempt to use those features.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supported_ca_certificate_identifiers ⇒ Array<String>
A list of the supported CA certificate identifiers.
For more information, see Updating Your Amazon DocumentDB TLS Certificates and Encrypting Data in Transit in the Amazon DocumentDB Developer Guide.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_certificate_rotation_without_restart ⇒ Boolean
Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
A value that indicates whether the engine version supports exporting
the log types specified by ExportableLogTypes to CloudWatch Logs.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-docdb/types.rb', line 2046 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :valid_upgrade_target, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supported_ca_certificate_identifiers, :supports_certificate_rotation_without_restart, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |