Class: Aws::DocDB::Types::DBEngineVersionMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Represents the output of DescribeDBEngineVersions.

Instance Attribute Summary collapse

Instance Attribute Details

#db_engine_versionsArray<Types::DBEngineVersion>

Detailed information about one or more DB engine versions.

Returns:



1536
1537
1538
1539
1540
# File 'lib/aws-sdk-docdb/types.rb', line 1536

class DBEngineVersionMessage < Struct.new(
  :marker,
  :db_engine_versions)
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


1536
1537
1538
1539
1540
# File 'lib/aws-sdk-docdb/types.rb', line 1536

class DBEngineVersionMessage < Struct.new(
  :marker,
  :db_engine_versions)
  include Aws::Structure
end