Class: Aws::DocDB::Types::DBInstanceMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Represents the output of DescribeDBInstances.

Instance Attribute Summary collapse

Instance Attribute Details

#db_instancesArray<Types::DBInstance>

Detailed information about one or more DB instances.

Returns:



1715
1716
1717
1718
1719
# File 'lib/aws-sdk-docdb/types.rb', line 1715

class DBInstanceMessage < Struct.new(
  :marker,
  :db_instances)
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


1715
1716
1717
1718
1719
# File 'lib/aws-sdk-docdb/types.rb', line 1715

class DBInstanceMessage < Struct.new(
  :marker,
  :db_instances)
  include Aws::Structure
end