Class: Aws::DocDB::Types::DBSubnetGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBSubnetGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Detailed information about a subnet group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_subnet_group_arn ⇒ String
The Amazon Resource Name (ARN) for the DB subnet group.
-
#db_subnet_group_description ⇒ String
Provides the description of the subnet group.
-
#db_subnet_group_name ⇒ String
The name of the subnet group.
-
#subnet_group_status ⇒ String
Provides the status of the subnet group.
-
#subnets ⇒ Array<Types::Subnet>
Detailed information about one or more subnets within a subnet group.
-
#supported_network_types ⇒ Array<String>
The network type of the DB subnet group.
-
#vpc_id ⇒ String
Provides the virtual private cloud (VPC) ID of the subnet group.
Instance Attribute Details
#db_subnet_group_arn ⇒ String
The Amazon Resource Name (ARN) for the DB subnet group.
2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-docdb/types.rb', line 2411 class DBSubnetGroup < Struct.new( :db_subnet_group_name, :db_subnet_group_description, :vpc_id, :subnet_group_status, :subnets, :db_subnet_group_arn, :supported_network_types) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group_description ⇒ String
Provides the description of the subnet group.
2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-docdb/types.rb', line 2411 class DBSubnetGroup < Struct.new( :db_subnet_group_name, :db_subnet_group_description, :vpc_id, :subnet_group_status, :subnets, :db_subnet_group_arn, :supported_network_types) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group_name ⇒ String
The name of the subnet group.
2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-docdb/types.rb', line 2411 class DBSubnetGroup < Struct.new( :db_subnet_group_name, :db_subnet_group_description, :vpc_id, :subnet_group_status, :subnets, :db_subnet_group_arn, :supported_network_types) SENSITIVE = [] include Aws::Structure end |
#subnet_group_status ⇒ String
Provides the status of the subnet group.
2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-docdb/types.rb', line 2411 class DBSubnetGroup < Struct.new( :db_subnet_group_name, :db_subnet_group_description, :vpc_id, :subnet_group_status, :subnets, :db_subnet_group_arn, :supported_network_types) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<Types::Subnet>
Detailed information about one or more subnets within a subnet group.
2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-docdb/types.rb', line 2411 class DBSubnetGroup < Struct.new( :db_subnet_group_name, :db_subnet_group_description, :vpc_id, :subnet_group_status, :subnets, :db_subnet_group_arn, :supported_network_types) SENSITIVE = [] include Aws::Structure end |
#supported_network_types ⇒ Array<String>
The network type of the DB subnet group.
Valid Values: IPV4 | DUAL
A DBSubnetGroup can support only the IPv4 protocol or the IPv4 and
the IPv6 protocols (DUAL).
2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-docdb/types.rb', line 2411 class DBSubnetGroup < Struct.new( :db_subnet_group_name, :db_subnet_group_description, :vpc_id, :subnet_group_status, :subnets, :db_subnet_group_arn, :supported_network_types) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
Provides the virtual private cloud (VPC) ID of the subnet group.
2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-docdb/types.rb', line 2411 class DBSubnetGroup < Struct.new( :db_subnet_group_name, :db_subnet_group_description, :vpc_id, :subnet_group_status, :subnets, :db_subnet_group_arn, :supported_network_types) SENSITIVE = [] include Aws::Structure end |