Class: Aws::DocDB::Types::DeleteDBClusterMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DeleteDBClusterMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Represents the input to DeleteDBCluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster_identifier ⇒ String
The cluster identifier for the cluster to be deleted.
-
#final_db_snapshot_identifier ⇒ String
The cluster snapshot identifier of the new cluster snapshot created when
SkipFinalSnapshotis set tofalse. -
#skip_final_snapshot ⇒ Boolean
Determines whether a final cluster snapshot is created before the cluster is deleted.
Instance Attribute Details
#db_cluster_identifier ⇒ String
The cluster identifier for the cluster to be deleted. This parameter isn’t case sensitive.
Constraints:
-
Must match an existing
DBClusterIdentifier.
^
2445 2446 2447 2448 2449 2450 2451 |
# File 'lib/aws-sdk-docdb/types.rb', line 2445 class DeleteDBClusterMessage < Struct.new( :db_cluster_identifier, :skip_final_snapshot, :final_db_snapshot_identifier) SENSITIVE = [] include Aws::Structure end |
#final_db_snapshot_identifier ⇒ String
The cluster snapshot identifier of the new cluster snapshot created when SkipFinalSnapshot is set to false.
<note markdown=“1”> Specifying this parameter and also setting the SkipFinalShapshot parameter to true results in an error.
</note>
Constraints:
-
Must be from 1 to 255 letters, numbers, or hyphens.
-
The first character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
2445 2446 2447 2448 2449 2450 2451 |
# File 'lib/aws-sdk-docdb/types.rb', line 2445 class DeleteDBClusterMessage < Struct.new( :db_cluster_identifier, :skip_final_snapshot, :final_db_snapshot_identifier) SENSITIVE = [] include Aws::Structure end |
#skip_final_snapshot ⇒ Boolean
Determines whether a final cluster snapshot is created before the cluster is deleted. If true is specified, no cluster snapshot is created. If false is specified, a cluster snapshot is created before the DB cluster is deleted.
<note markdown=“1”> If SkipFinalSnapshot is false, you must specify a FinalDBSnapshotIdentifier parameter.
</note>
Default: false
2445 2446 2447 2448 2449 2450 2451 |
# File 'lib/aws-sdk-docdb/types.rb', line 2445 class DeleteDBClusterMessage < Struct.new( :db_cluster_identifier, :skip_final_snapshot, :final_db_snapshot_identifier) SENSITIVE = [] include Aws::Structure end |