Class: Aws::DocDB::Types::DescribeCertificatesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DescribeCertificatesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_identifier ⇒ String
The user-supplied certificate identifier.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeCertificatesrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#certificate_identifier ⇒ String
The user-supplied certificate identifier. If this parameter is
specified, information for only the specified certificate is
returned. If this parameter is omitted, a list of up to MaxRecords
certificates is returned. This parameter is not case sensitive.
Constraints
- Must match an existing
CertificateIdentifier.
^
2754 2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-docdb/types.rb', line 2754 class DescribeCertificatesMessage < Struct.new( :certificate_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
2754 2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-docdb/types.rb', line 2754 class DescribeCertificatesMessage < Struct.new( :certificate_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeCertificates request. If this parameter is specified, the
response includes only records beyond the marker, up to the value
specified by MaxRecords.
2754 2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-docdb/types.rb', line 2754 class DescribeCertificatesMessage < Struct.new( :certificate_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that the
remaining results can be retrieved.
Default: 100
Constraints:
-
Minimum: 20
-
Maximum: 100
2754 2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-docdb/types.rb', line 2754 class DescribeCertificatesMessage < Struct.new( :certificate_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |