Class: Aws::DocDB::Types::DescribeDBClusterParameterGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DescribeDBClusterParameterGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass DescribeDBClusterParameterGroupsMessage data as a hash:
{
db_cluster_parameter_group_name: "String",
filters: [
{
name: "String", # required
values: ["String"], # required
},
],
max_records: 1,
marker: "String",
}
Represents the input to DescribeDBClusterParameterGroups.
Instance Attribute Summary collapse
-
#db_cluster_parameter_group_name ⇒ String
The name of a specific DB cluster parameter group to return details for.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_cluster_parameter_group_name ⇒ String
The name of a specific DB cluster parameter group to return details for.
Constraints:
-
If provided, must match the name of an existing
DBClusterParameterGroup.
^
2068 2069 2070 2071 2072 2073 2074 |
# File 'lib/aws-sdk-docdb/types.rb', line 2068 class DescribeDBClusterParameterGroupsMessage < Struct.new( :db_cluster_parameter_group_name, :filters, :max_records, :marker) include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
2068 2069 2070 2071 2072 2073 2074 |
# File 'lib/aws-sdk-docdb/types.rb', line 2068 class DescribeDBClusterParameterGroupsMessage < Struct.new( :db_cluster_parameter_group_name, :filters, :max_records, :marker) include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
2068 2069 2070 2071 2072 2073 2074 |
# File 'lib/aws-sdk-docdb/types.rb', line 2068 class DescribeDBClusterParameterGroupsMessage < Struct.new( :db_cluster_parameter_group_name, :filters, :max_records, :marker) include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
2068 2069 2070 2071 2072 2073 2074 |
# File 'lib/aws-sdk-docdb/types.rb', line 2068 class DescribeDBClusterParameterGroupsMessage < Struct.new( :db_cluster_parameter_group_name, :filters, :max_records, :marker) include Aws::Structure end |