Class: Aws::DocDB::Types::DescribeDBClusterParametersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DescribeDBClusterParametersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Represents the input to DescribeDBClusterParameters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster_parameter_group_name ⇒ String
The name of a specific cluster parameter group to return parameter details for.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source ⇒ String
A value that indicates to return only parameters for a specific source.
Instance Attribute Details
#db_cluster_parameter_group_name ⇒ String
The name of a specific cluster parameter group to return parameter details for.
Constraints:
-
If provided, must match the name of an existing
DBClusterParameterGroup.
^
2681 2682 2683 2684 2685 2686 2687 2688 2689 |
# File 'lib/aws-sdk-docdb/types.rb', line 2681 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
2681 2682 2683 2684 2685 2686 2687 2688 2689 |
# File 'lib/aws-sdk-docdb/types.rb', line 2681 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
2681 2682 2683 2684 2685 2686 2687 2688 2689 |
# File 'lib/aws-sdk-docdb/types.rb', line 2681 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
2681 2682 2683 2684 2685 2686 2687 2688 2689 |
# File 'lib/aws-sdk-docdb/types.rb', line 2681 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
A value that indicates to return only parameters for a specific source. Parameter sources can be engine, service, or customer.
2681 2682 2683 2684 2685 2686 2687 2688 2689 |
# File 'lib/aws-sdk-docdb/types.rb', line 2681 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |