Class: Aws::DocDB::Types::DescribeDBClusterSnapshotsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Note:

When making an API call, you may pass DescribeDBClusterSnapshotsMessage data as a hash:

{
  db_cluster_identifier: "String",
  db_cluster_snapshot_identifier: "String",
  snapshot_type: "String",
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
  max_records: 1,
  marker: "String",
  include_shared: false,
  include_public: false,
}

Represents the input to DescribeDBClusterSnapshots.

Instance Attribute Summary collapse

Instance Attribute Details

#db_cluster_identifierString

The ID of the DB cluster to retrieve the list of DB cluster snapshots for. This parameter can’t be used with the DBClusterSnapshotIdentifier parameter. This parameter is not case sensitive.

Constraints:

  • If provided, must match the identifier of an existing DBCluster.

^

Returns:

  • (String)


2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-docdb/types.rb', line 2289

class DescribeDBClusterSnapshotsMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :snapshot_type,
  :filters,
  :max_records,
  :marker,
  :include_shared,
  :include_public)
  include Aws::Structure
end

#db_cluster_snapshot_identifierString

A specific DB cluster snapshot identifier to describe. This parameter can’t be used with the DBClusterIdentifier parameter. This value is stored as a lowercase string.

Constraints:

  • If provided, must match the identifier of an existing DBClusterSnapshot.

  • If this identifier is for an automated snapshot, the SnapshotType parameter must also be specified.

Returns:

  • (String)


2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-docdb/types.rb', line 2289

class DescribeDBClusterSnapshotsMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :snapshot_type,
  :filters,
  :max_records,
  :marker,
  :include_shared,
  :include_public)
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter is not currently supported.

Returns:



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-docdb/types.rb', line 2289

class DescribeDBClusterSnapshotsMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :snapshot_type,
  :filters,
  :max_records,
  :marker,
  :include_shared,
  :include_public)
  include Aws::Structure
end

#include_publicBoolean

Set to true to include manual DB cluster snapshots that are public and can be copied or restored by any AWS account, and otherwise false. The default is false.

Returns:

  • (Boolean)


2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-docdb/types.rb', line 2289

class DescribeDBClusterSnapshotsMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :snapshot_type,
  :filters,
  :max_records,
  :marker,
  :include_shared,
  :include_public)
  include Aws::Structure
end

#include_sharedBoolean

Set to true to include shared manual DB cluster snapshots from other AWS accounts that this AWS account has been given permission to copy or restore, and otherwise false. The default is false.

Returns:

  • (Boolean)


2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-docdb/types.rb', line 2289

class DescribeDBClusterSnapshotsMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :snapshot_type,
  :filters,
  :max_records,
  :marker,
  :include_shared,
  :include_public)
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-docdb/types.rb', line 2289

class DescribeDBClusterSnapshotsMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :snapshot_type,
  :filters,
  :max_records,
  :marker,
  :include_shared,
  :include_public)
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.

Returns:

  • (Integer)


2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-docdb/types.rb', line 2289

class DescribeDBClusterSnapshotsMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :snapshot_type,
  :filters,
  :max_records,
  :marker,
  :include_shared,
  :include_public)
  include Aws::Structure
end

#snapshot_typeString

The type of DB cluster snapshots to be returned. You can specify one of the following values:

  • automated - Return all DB cluster snapshots that Amazon DocumentDB has automatically created for your AWS account.

  • manual - Return all DB cluster snapshots that you have manually created for your AWS account.

  • shared - Return all manual DB cluster snapshots that have been shared to your AWS account.

  • public - Return all DB cluster snapshots that have been marked as public.

If you don’t specify a SnapshotType value, then both automated and manual DB cluster snapshots are returned. You can include shared DB cluster snapshots with these results by setting the IncludeShared parameter to true. You can include public DB cluster snapshots with these results by setting the IncludePublic parameter to true.

The IncludeShared and IncludePublic parameters don’t apply for SnapshotType values of manual or automated. The IncludePublic parameter doesn’t apply when SnapshotType is set to shared. The IncludeShared parameter doesn’t apply when SnapshotType is set to public.

Returns:

  • (String)


2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-docdb/types.rb', line 2289

class DescribeDBClusterSnapshotsMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_snapshot_identifier,
  :snapshot_type,
  :filters,
  :max_records,
  :marker,
  :include_shared,
  :include_public)
  include Aws::Structure
end