Class: Aws::DocDB::Types::DescribeDBClustersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DescribeDBClustersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass DescribeDBClustersMessage data as a hash:
{
db_cluster_identifier: "String",
filters: [
{
name: "String", # required
values: ["String"], # required
},
],
max_records: 1,
marker: "String",
}
Represents the input to DescribeDBClusters.
Instance Attribute Summary collapse
-
#db_cluster_identifier ⇒ String
The user-provided DB cluster identifier.
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB clusters to describe.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_cluster_identifier ⇒ String
The user-provided DB cluster identifier. If this parameter is specified, information from only the specific DB cluster is returned. This parameter isn’t case sensitive.
Constraints:
-
If provided, must match an existing
DBClusterIdentifier.
^
2361 2362 2363 2364 2365 2366 2367 |
# File 'lib/aws-sdk-docdb/types.rb', line 2361 class DescribeDBClustersMessage < Struct.new( :db_cluster_identifier, :filters, :max_records, :marker) include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB clusters to describe.
Supported filters:
-
db-cluster-id- Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list only includes information about the DB clusters identified by these ARNs.
^
2361 2362 2363 2364 2365 2366 2367 |
# File 'lib/aws-sdk-docdb/types.rb', line 2361 class DescribeDBClustersMessage < Struct.new( :db_cluster_identifier, :filters, :max_records, :marker) include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
2361 2362 2363 2364 2365 2366 2367 |
# File 'lib/aws-sdk-docdb/types.rb', line 2361 class DescribeDBClustersMessage < Struct.new( :db_cluster_identifier, :filters, :max_records, :marker) include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
2361 2362 2363 2364 2365 2366 2367 |
# File 'lib/aws-sdk-docdb/types.rb', line 2361 class DescribeDBClustersMessage < Struct.new( :db_cluster_identifier, :filters, :max_records, :marker) include Aws::Structure end |