Class: Aws::DocDB::Types::DescribeDBEngineVersionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Note:

When making an API call, you may pass DescribeDBEngineVersionsMessage data as a hash:

{
  engine: "String",
  engine_version: "String",
  db_parameter_group_family: "String",
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
  max_records: 1,
  marker: "String",
  default_only: false,
  list_supported_character_sets: false,
  list_supported_timezones: false,
}

Represents the input to DescribeDBEngineVersions.

Instance Attribute Summary collapse

Instance Attribute Details

#db_parameter_group_familyString

The name of a specific DB parameter group family to return details for.

Constraints:

  • If provided, must match an existing DBParameterGroupFamily.

^



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end

#default_onlyBoolean

Indicates that only the default version of the specified engine or engine and major version combination is returned.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end

#engineString

The database engine to return.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end

#engine_versionString

The database engine version to return.

Example: 5.1.49



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter is not currently supported.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end

#list_supported_character_setsBoolean

If this parameter is specified and the requested engine supports the CharacterSetName parameter for CreateDBInstance, the response includes a list of supported character sets for each engine version.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end

#list_supported_timezonesBoolean

If this parameter is specified and the requested engine supports the TimeZone parameter for CreateDBInstance, the response includes a list of supported time zones for each engine version.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-docdb/types.rb', line 2452

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  include Aws::Structure
end