Class: Aws::DocDB::Types::DescribeDBInstancesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DescribeDBInstancesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass DescribeDBInstancesMessage data as a hash:
{
db_instance_identifier: "String",
filters: [
{
name: "String", # required
values: ["String"], # required
},
],
max_records: 1,
marker: "String",
}
Represents the input to DescribeDBInstances.
Instance Attribute Summary collapse
-
#db_instance_identifier ⇒ String
The user-provided instance identifier.
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB instances to describe.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_instance_identifier ⇒ String
The user-provided instance identifier. If this parameter is specified, information from only the specific DB instance is returned. This parameter isn’t case sensitive.
Constraints:
-
If provided, must match the identifier of an existing
DBInstance.
^
2529 2530 2531 2532 2533 2534 2535 |
# File 'lib/aws-sdk-docdb/types.rb', line 2529 class DescribeDBInstancesMessage < Struct.new( :db_instance_identifier, :filters, :max_records, :marker) include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB instances to describe.
Supported filters:
-
db-cluster-id- Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list includes only the information about the DB instances that are associated with the DB clusters that are identified by these ARNs. -
db-instance-id- Accepts DB instance identifiers and DB instance ARNs. The results list includes only the information about the DB instances that are identified by these ARNs.
2529 2530 2531 2532 2533 2534 2535 |
# File 'lib/aws-sdk-docdb/types.rb', line 2529 class DescribeDBInstancesMessage < Struct.new( :db_instance_identifier, :filters, :max_records, :marker) include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
2529 2530 2531 2532 2533 2534 2535 |
# File 'lib/aws-sdk-docdb/types.rb', line 2529 class DescribeDBInstancesMessage < Struct.new( :db_instance_identifier, :filters, :max_records, :marker) include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
2529 2530 2531 2532 2533 2534 2535 |
# File 'lib/aws-sdk-docdb/types.rb', line 2529 class DescribeDBInstancesMessage < Struct.new( :db_instance_identifier, :filters, :max_records, :marker) include Aws::Structure end |