Class: Aws::DocDB::Types::DescribeEventsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DescribeEventsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Represents the input to DescribeEvents.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
The number of minutes to retrieve events for.
-
#end_time ⇒ Time
The end of the time interval for which to retrieve events, specified in ISO 8601 format.
-
#event_categories ⇒ Array<String>
A list of event categories that trigger notifications for an event notification subscription.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source_identifier ⇒ String
The identifier of the event source for which events are returned.
-
#source_type ⇒ String
The event source to retrieve events for.
-
#start_time ⇒ Time
The beginning of the time interval to retrieve events for, specified in ISO 8601 format.
Instance Attribute Details
#duration ⇒ Integer
The number of minutes to retrieve events for.
Default: 60
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end of the time interval for which to retrieve events, specified in ISO 8601 format.
Example: 2009-07-08T18:00Z
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#event_categories ⇒ Array<String>
A list of event categories that trigger notifications for an event notification subscription.
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source_identifier ⇒ String
The identifier of the event source for which events are returned. If not specified, then all sources are included in the response.
Constraints:
-
If
SourceIdentifieris provided,SourceTypemust also be provided. -
If the source type is
DBInstance, aDBInstanceIdentifiermust be provided. -
If the source type is
DBSecurityGroup, aDBSecurityGroupNamemust be provided. -
If the source type is
DBParameterGroup, aDBParameterGroupNamemust be provided. -
If the source type is
DBSnapshot, aDBSnapshotIdentifiermust be provided. -
Cannot end with a hyphen or contain two consecutive hyphens.
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The event source to retrieve events for. If no value is specified, all events are returned.
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The beginning of the time interval to retrieve events for, specified in ISO 8601 format.
Example: 2009-07-08T18:00Z
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/aws-sdk-docdb/types.rb', line 3327 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |