Class: Aws::DocDB::Types::DescribeGlobalClustersMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

A filter that specifies one or more global DB clusters to describe.

Supported filters: db-cluster-id accepts cluster identifiers and cluster Amazon Resource Names (ARNs). The results list will only include information about the clusters identified by these ARNs.



3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-docdb/types.rb', line 3371

class DescribeGlobalClustersMessage < Struct.new(
  :global_cluster_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#global_cluster_identifierString

The user-supplied cluster identifier. If this parameter is specified, information from only the specific cluster is returned. This parameter isn’t case-sensitive.



3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-docdb/types.rb', line 3371

class DescribeGlobalClustersMessage < Struct.new(
  :global_cluster_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeGlobalClusters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-docdb/types.rb', line 3371

class DescribeGlobalClustersMessage < Struct.new(
  :global_cluster_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.



3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-docdb/types.rb', line 3371

class DescribeGlobalClustersMessage < Struct.new(
  :global_cluster_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end