Class: Aws::DocDB::Types::DescribeOrderableDBInstanceOptionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Note:

When making an API call, you may pass DescribeOrderableDBInstanceOptionsMessage data as a hash:

{
  engine: "String", # required
  engine_version: "String",
  db_instance_class: "String",
  license_model: "String",
  vpc: false,
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
  max_records: 1,
  marker: "String",
}

Represents the input to DescribeOrderableDBInstanceOptions.

Instance Attribute Summary collapse

Instance Attribute Details

#db_instance_classString

The DB instance class filter value. Specify this parameter to show only the available offerings that match the specified DB instance class.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-docdb/types.rb', line 2869

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  include Aws::Structure
end

#engineString

The name of the engine to retrieve DB instance options for.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-docdb/types.rb', line 2869

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  include Aws::Structure
end

#engine_versionString

The engine version filter value. Specify this parameter to show only the available offerings that match the specified engine version.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-docdb/types.rb', line 2869

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter is not currently supported.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-docdb/types.rb', line 2869

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  include Aws::Structure
end

#license_modelString

The license model filter value. Specify this parameter to show only the available offerings that match the specified license model.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-docdb/types.rb', line 2869

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-docdb/types.rb', line 2869

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-docdb/types.rb', line 2869

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  include Aws::Structure
end

#vpcBoolean

The virtual private cloud (VPC) filter value. Specify this parameter to show only the available VPC or non-VPC offerings.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-docdb/types.rb', line 2869

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  include Aws::Structure
end