Class: Aws::DocDB::Types::Endpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::Endpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Network information for accessing a DB cluster or DB instance. Client programs must specify a valid endpoint to access these Amazon DocumentDB resources.
Instance Attribute Summary collapse
-
#address ⇒ String
Specifies the DNS address of the DB instance.
-
#hosted_zone_id ⇒ String
Specifies the ID that Amazon Route 53 assigns when you create a hosted zone.
-
#port ⇒ Integer
Specifies the port that the database engine is listening on.
Instance Attribute Details
#address ⇒ String
Specifies the DNS address of the DB instance.
2964 2965 2966 2967 2968 2969 |
# File 'lib/aws-sdk-docdb/types.rb', line 2964 class Endpoint < Struct.new( :address, :port, :hosted_zone_id) include Aws::Structure end |
#hosted_zone_id ⇒ String
Specifies the ID that Amazon Route 53 assigns when you create a hosted zone.
2964 2965 2966 2967 2968 2969 |
# File 'lib/aws-sdk-docdb/types.rb', line 2964 class Endpoint < Struct.new( :address, :port, :hosted_zone_id) include Aws::Structure end |
#port ⇒ Integer
Specifies the port that the database engine is listening on.
2964 2965 2966 2967 2968 2969 |
# File 'lib/aws-sdk-docdb/types.rb', line 2964 class Endpoint < Struct.new( :address, :port, :hosted_zone_id) include Aws::Structure end |