Class: Aws::DocDB::Types::EventSubscription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Detailed information about an event to which you have subscribed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cust_subscription_idString

The Amazon DocumentDB event notification subscription ID.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#customer_aws_idString

The Amazon Web Services customer account that is associated with the Amazon DocumentDB event notification subscription.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

A Boolean value indicating whether the subscription is enabled. A value of true indicates that the subscription is enabled.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#event_categories_listArray<String>

A list of event categories for the Amazon DocumentDB event notification subscription.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#event_subscription_arnString

The Amazon Resource Name (ARN) for the event subscription.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arnString

The topic ARN of the Amazon DocumentDB event notification subscription.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_ids_listArray<String>

A list of source IDs for the Amazon DocumentDB event notification subscription.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The source type for the Amazon DocumentDB event notification subscription.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Amazon DocumentDB event notification subscription.

Constraints:

Can be one of the following: creating, modifying, deleting, active, no-permission, topic-not-exist

The no-permission status indicates that Amazon DocumentDB no longer has permission to post to the SNS topic. The topic-not-exist status indicates that the topic was deleted after the subscription was created.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_creation_timeString

The time at which the Amazon DocumentDB event notification subscription was created.



3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/aws-sdk-docdb/types.rb', line 3679

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :enabled,
  :event_subscription_arn)
  SENSITIVE = []
  include Aws::Structure
end