Class: Aws::DocDB::Types::EventsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Represents the output of DescribeEvents.

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::Event>

Detailed information about one or more events.

Returns:



3081
3082
3083
3084
3085
# File 'lib/aws-sdk-docdb/types.rb', line 3081

class EventsMessage < Struct.new(
  :marker,
  :events)
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


3081
3082
3083
3084
3085
# File 'lib/aws-sdk-docdb/types.rb', line 3081

class EventsMessage < Struct.new(
  :marker,
  :events)
  include Aws::Structure
end