Class: Aws::DocDB::Types::ModifyDBClusterSnapshotAttributeMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::ModifyDBClusterSnapshotAttributeMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass ModifyDBClusterSnapshotAttributeMessage data as a hash:
{
db_cluster_snapshot_identifier: "String", # required
attribute_name: "String", # required
values_to_add: ["String"],
values_to_remove: ["String"],
}
Represents the input to ModifyDBClusterSnapshotAttribute.
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
The name of the DB cluster snapshot attribute to modify.
-
#db_cluster_snapshot_identifier ⇒ String
The identifier for the DB cluster snapshot to modify the attributes for.
-
#values_to_add ⇒ Array<String>
A list of DB cluster snapshot attributes to add to the attribute specified by
AttributeName. -
#values_to_remove ⇒ Array<String>
A list of DB cluster snapshot attributes to remove from the attribute specified by
AttributeName.
Instance Attribute Details
#attribute_name ⇒ String
The name of the DB cluster snapshot attribute to modify.
To manage authorization for other AWS accounts to copy or restore a manual DB cluster snapshot, set this value to restore.
3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-docdb/types.rb', line 3479 class ModifyDBClusterSnapshotAttributeMessage < Struct.new( :db_cluster_snapshot_identifier, :attribute_name, :values_to_add, :values_to_remove) include Aws::Structure end |
#db_cluster_snapshot_identifier ⇒ String
The identifier for the DB cluster snapshot to modify the attributes for.
3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-docdb/types.rb', line 3479 class ModifyDBClusterSnapshotAttributeMessage < Struct.new( :db_cluster_snapshot_identifier, :attribute_name, :values_to_add, :values_to_remove) include Aws::Structure end |
#values_to_add ⇒ Array<String>
A list of DB cluster snapshot attributes to add to the attribute specified by AttributeName.
To authorize other AWS accounts to copy or restore a manual DB cluster snapshot, set this list to include one or more AWS account IDs. To make the manual DB cluster snapshot restorable by any AWS account, set it to all. Do not add the all value for any manual DB cluster snapshots that contain private information that you don’t want to be available to all AWS accounts.
3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-docdb/types.rb', line 3479 class ModifyDBClusterSnapshotAttributeMessage < Struct.new( :db_cluster_snapshot_identifier, :attribute_name, :values_to_add, :values_to_remove) include Aws::Structure end |
#values_to_remove ⇒ Array<String>
A list of DB cluster snapshot attributes to remove from the attribute specified by AttributeName.
To remove authorization for other AWS accounts to copy or restore a manual DB cluster snapshot, set this list to include one or more AWS account identifiers. To remove authorization for any AWS account to copy or restore the DB cluster snapshot, set it to all . If you specify all, an AWS account whose account ID is explicitly added to the restore attribute can still copy or restore a manual DB cluster snapshot.
3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-docdb/types.rb', line 3479 class ModifyDBClusterSnapshotAttributeMessage < Struct.new( :db_cluster_snapshot_identifier, :attribute_name, :values_to_add, :values_to_remove) include Aws::Structure end |