Class: Aws::DocDB::Types::ModifyDBClusterSnapshotAttributeResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::ModifyDBClusterSnapshotAttributeResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Instance Attribute Summary collapse
-
#db_cluster_snapshot_attributes_result ⇒ Types::DBClusterSnapshotAttributesResult
Detailed information about the attributes that are associated with a DB cluster snapshot.
Instance Attribute Details
#db_cluster_snapshot_attributes_result ⇒ Types::DBClusterSnapshotAttributesResult
Detailed information about the attributes that are associated with a DB cluster snapshot.
3494 3495 3496 3497 |
# File 'lib/aws-sdk-docdb/types.rb', line 3494 class ModifyDBClusterSnapshotAttributeResult < Struct.new( :db_cluster_snapshot_attributes_result) include Aws::Structure end |