Class: Aws::DocDB::Types::ModifyDBInstanceMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::ModifyDBInstanceMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass ModifyDBInstanceMessage data as a hash:
{
db_instance_identifier: "String", # required
db_instance_class: "String",
apply_immediately: false,
preferred_maintenance_window: "String",
auto_minor_version_upgrade: false,
new_db_instance_identifier: "String",
promotion_tier: 1,
}
Represents the input to ModifyDBInstance.
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
Specifies whether the modifications in this request and any pending modifications are asynchronously applied as soon as possible, regardless of the
PreferredMaintenanceWindowsetting for the DB instance. -
#auto_minor_version_upgrade ⇒ Boolean
Indicates that minor version upgrades are applied automatically to the DB instance during the maintenance window.
-
#db_instance_class ⇒ String
The new compute and memory capacity of the DB instance; for example,
db.r5.large. -
#db_instance_identifier ⇒ String
The DB instance identifier.
-
#new_db_instance_identifier ⇒ String
The new DB instance identifier for the DB instance when renaming a DB instance.
-
#preferred_maintenance_window ⇒ String
The weekly time range (in UTC) during which system maintenance can occur, which might result in an outage.
-
#promotion_tier ⇒ Integer
A value that specifies the order in which an Amazon DocumentDB replica is promoted to the primary instance after a failure of the existing primary instance.
Instance Attribute Details
#apply_immediately ⇒ Boolean
Specifies whether the modifications in this request and any pending modifications are asynchronously applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the DB instance.
If this parameter is set to false, changes to the DB instance are applied during the next maintenance window. Some parameter changes can cause an outage and are applied on the next reboot.
Default: false
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-docdb/types.rb', line 3612 class ModifyDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :apply_immediately, :preferred_maintenance_window, :auto_minor_version_upgrade, :new_db_instance_identifier, :promotion_tier) include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
Indicates that minor version upgrades are applied automatically to the DB instance during the maintenance window. Changing this parameter doesn’t result in an outage except in the following case, and the change is asynchronously applied as soon as possible. An outage results if this parameter is set to true during the maintenance window, and a newer minor version is available, and Amazon DocumentDB has enabled automatic patching for that engine version.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-docdb/types.rb', line 3612 class ModifyDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :apply_immediately, :preferred_maintenance_window, :auto_minor_version_upgrade, :new_db_instance_identifier, :promotion_tier) include Aws::Structure end |
#db_instance_class ⇒ String
The new compute and memory capacity of the DB instance; for example, db.r5.large. Not all DB instance classes are available in all AWS Regions.
If you modify the DB instance class, an outage occurs during the change. The change is applied during the next maintenance window, unless ApplyImmediately is specified as true for this request.
Default: Uses existing setting.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-docdb/types.rb', line 3612 class ModifyDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :apply_immediately, :preferred_maintenance_window, :auto_minor_version_upgrade, :new_db_instance_identifier, :promotion_tier) include Aws::Structure end |
#db_instance_identifier ⇒ String
The DB instance identifier. This value is stored as a lowercase string.
Constraints:
-
Must match the identifier of an existing
DBInstance.
^
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-docdb/types.rb', line 3612 class ModifyDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :apply_immediately, :preferred_maintenance_window, :auto_minor_version_upgrade, :new_db_instance_identifier, :promotion_tier) include Aws::Structure end |
#new_db_instance_identifier ⇒ String
The new DB instance identifier for the DB instance when renaming a DB instance. When you change the DB instance identifier, an instance reboot occurs immediately if you set ‘Apply Immediately` to true. It occurs during the next maintenance window if you set `Apply Immediately` to false. This value is stored as a lowercase string.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens.
-
The first character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
Example: mydbinstance
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-docdb/types.rb', line 3612 class ModifyDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :apply_immediately, :preferred_maintenance_window, :auto_minor_version_upgrade, :new_db_instance_identifier, :promotion_tier) include Aws::Structure end |
#preferred_maintenance_window ⇒ String
The weekly time range (in UTC) during which system maintenance can occur, which might result in an outage. Changing this parameter doesn’t result in an outage except in the following situation, and the change is asynchronously applied as soon as possible. If there are pending actions that cause a reboot, and the maintenance window is changed to include the current time, changing this parameter causes a reboot of the DB instance. If you are moving this window to the current time, there must be at least 30 minutes between the current time and end of the window to ensure that pending changes are applied.
Default: Uses existing setting.
Format: ddd:hh24:mi-ddd:hh24:mi
Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun
Constraints: Must be at least 30 minutes.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-docdb/types.rb', line 3612 class ModifyDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :apply_immediately, :preferred_maintenance_window, :auto_minor_version_upgrade, :new_db_instance_identifier, :promotion_tier) include Aws::Structure end |
#promotion_tier ⇒ Integer
A value that specifies the order in which an Amazon DocumentDB replica is promoted to the primary instance after a failure of the existing primary instance.
Default: 1
Valid values: 0-15
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 |
# File 'lib/aws-sdk-docdb/types.rb', line 3612 class ModifyDBInstanceMessage < Struct.new( :db_instance_identifier, :db_instance_class, :apply_immediately, :preferred_maintenance_window, :auto_minor_version_upgrade, :new_db_instance_identifier, :promotion_tier) include Aws::Structure end |