Class: Aws::DocDB::Types::OrderableDBInstanceOptionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Represents the output of DescribeOrderableDBInstanceOptions.

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


3736
3737
3738
3739
3740
# File 'lib/aws-sdk-docdb/types.rb', line 3736

class OrderableDBInstanceOptionsMessage < Struct.new(
  :orderable_db_instance_options,
  :marker)
  include Aws::Structure
end

#orderable_db_instance_optionsArray<Types::OrderableDBInstanceOption>

The options that are available for a particular orderable DB instance.



3736
3737
3738
3739
3740
# File 'lib/aws-sdk-docdb/types.rb', line 3736

class OrderableDBInstanceOptionsMessage < Struct.new(
  :orderable_db_instance_options,
  :marker)
  include Aws::Structure
end