Class: Aws::DocDB::Types::Parameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::Parameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Detailed information about an individual parameter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ String
Specifies the valid range of values for the parameter.
-
#apply_method ⇒ String
Indicates when to apply parameter updates.
-
#apply_type ⇒ String
Specifies the engine-specific parameters type.
-
#data_type ⇒ String
Specifies the valid data type for the parameter.
-
#description ⇒ String
Provides a description of the parameter.
-
#is_modifiable ⇒ Boolean
Indicates whether (
true) or not (false) the parameter can be modified. -
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
-
#parameter_name ⇒ String
Specifies the name of the parameter.
-
#parameter_value ⇒ String
Specifies the value of the parameter.
-
#source ⇒ String
Indicates the source of the parameter value.
Instance Attribute Details
#allowed_values ⇒ String
Specifies the valid range of values for the parameter.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#apply_method ⇒ String
Indicates when to apply parameter updates.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#apply_type ⇒ String
Specifies the engine-specific parameters type.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ String
Specifies the valid data type for the parameter.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Provides a description of the parameter.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#is_modifiable ⇒ Boolean
Indicates whether (true) or not (false) the parameter can be
modified. Some parameters have security or operational implications
that prevent them from being changed.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#parameter_name ⇒ String
Specifies the name of the parameter.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#parameter_value ⇒ String
Specifies the value of the parameter. Must be one or more of the
cluster parameter's AllowedValues in CSV format:
Valid values are:
-
enabled: The cluster accepts secure connections using TLS version 1.0 through 1.3. -
disabled: The cluster does not accept secure connections using TLS. -
fips-140-3: The cluster only accepts secure connections per the requirements of the Federal Information Processing Standards (FIPS) publication 140-3. Only supported starting with Amazon DocumentDB 5.0 (engine version 3.0.3727) clusters in these regions: ca-central-1, us-west-2, us-east-1, us-east-2, us-gov-east-1, us-gov-west-1. -
tls1.2+: The cluster accepts secure connections using TLS version 1.2 and above. Only supported starting with Amazon DocumentDB 4.0 (engine version 2.0.10980) and Amazon DocumentDB 5.0 (engine version 3.0.11051). -
tls1.3+: The cluster accepts secure connections using TLS version 1.3 and above. Only supported starting with Amazon DocumentDB 4.0 (engine version 2.0.10980) and Amazon DocumentDB 5.0 (engine version 3.0.11051).
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
Indicates the source of the parameter value.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 |
# File 'lib/aws-sdk-docdb/types.rb', line 5172 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |