Class: Aws::DocDB::Types::PendingModifiedValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

One or more modified settings for a DB instance. These modified settings have been requested, but haven’t been applied yet.

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

Contains the new AllocatedStorage size for the DB instance that will be applied or is currently being applied.

Returns:

  • (Integer)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#backup_retention_periodInteger

Specifies the pending number of days for which automated backups are retained.

Returns:

  • (Integer)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#ca_certificate_identifierString

Specifies the identifier of the certificate authority (CA) certificate for the DB instance.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#db_instance_classString

Contains the new DBInstanceClass for the DB instance that will be applied or is currently being applied.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#db_instance_identifierString

Contains the new DBInstanceIdentifier for the DB instance that will be applied or is currently being applied.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#db_subnet_group_nameString

The new DB subnet group for the DB instance.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#engine_versionString

Indicates the database engine version.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#iopsInteger

Specifies the new Provisioned IOPS value for the DB instance that will be applied or is currently being applied.

Returns:

  • (Integer)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#license_modelString

The license model for the DB instance.

Valid values: license-included, bring-your-own-license, general-public-license

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#master_user_passwordString

Contains the pending or currently in-progress change of the master credentials for the DB instance.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#multi_azBoolean

Indicates that the Single-AZ DB instance is to change to a Multi-AZ deployment.

Returns:

  • (Boolean)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#pending_cloudwatch_logs_exportsTypes::PendingCloudwatchLogsExports

A list of the log types whose configuration is still pending. These log types are in the process of being activated or deactivated.



3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#portInteger

Specifies the pending port for the DB instance.

Returns:

  • (Integer)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end

#storage_typeString

Specifies the storage type to be associated with the DB instance.

Returns:

  • (String)


3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-docdb/types.rb', line 3981

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  include Aws::Structure
end