Class: Aws::DocDB::Types::RestoreDBClusterToPointInTimeMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::RestoreDBClusterToPointInTimeMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Represents the input to RestoreDBClusterToPointInTime.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster_identifier ⇒ String
The name of the new cluster to be created.
-
#db_subnet_group_name ⇒ String
The subnet group name to use for the new cluster.
-
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted.
-
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that must be enabled for exporting to Amazon CloudWatch Logs.
-
#kms_key_id ⇒ String
The KMS key identifier to use when restoring an encrypted cluster from an encrypted cluster.
-
#network_type ⇒ String
The network type of the cluster.
-
#port ⇒ Integer
The port number on which the new cluster accepts connections.
-
#restore_to_time ⇒ Time
The date and time to restore the cluster to.
-
#restore_type ⇒ String
The type of restore to be performed.
-
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfiguration
Contains the scaling configuration of an Amazon DocumentDB Serverless cluster.
-
#source_db_cluster_identifier ⇒ String
The identifier of the source cluster from which to restore.
-
#storage_type ⇒ String
The storage type to associate with the DB cluster.
-
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the restored cluster.
-
#use_latest_restorable_time ⇒ Boolean
A value that is set to
trueto restore the cluster to the latest restorable backup time, andfalseotherwise. -
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security groups that the new cluster belongs to.
Instance Attribute Details
#db_cluster_identifier ⇒ String
The name of the new cluster to be created.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens.
-
The first character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group_name ⇒ String
The subnet group name to use for the new cluster.
Constraints: If provided, must match the name of an existing
DBSubnetGroup.
Example: mySubnetgroup
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted. If
DeletionProtection is enabled, the cluster cannot be deleted
unless it is modified and DeletionProtection is disabled.
DeletionProtection protects clusters from being accidentally
deleted.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that must be enabled for exporting to Amazon CloudWatch Logs.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The KMS key identifier to use when restoring an encrypted cluster from an encrypted cluster.
The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are restoring a cluster with the same Amazon Web Services account that owns the KMS encryption key used to encrypt the new cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key.
You can restore to a new cluster and encrypt the new cluster with an
KMS key that is different from the KMS key used to encrypt the
source cluster. The new DB cluster is encrypted with the KMS key
identified by the KmsKeyId parameter.
If you do not specify a value for the KmsKeyId parameter, then the
following occurs:
-
If the cluster is encrypted, then the restored cluster is encrypted using the KMS key that was used to encrypt the source cluster.
-
If the cluster is not encrypted, then the restored cluster is not encrypted.
If DBClusterIdentifier refers to a cluster that is not encrypted,
then the restore request is rejected.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
The network type of the cluster.
The network type is determined by the DBSubnetGroup specified for
the cluster. A DBSubnetGroup can support only the IPv4 protocol or
the IPv4 and the IPv6 protocols (DUAL).
For more information, see DocumentDB clusters in a VPC in the Amazon DocumentDB Developer Guide.
Valid Values: IPV4 | DUAL
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which the new cluster accepts connections.
Constraints: Must be a value from 1150 to 65535.
Default: The default port for the engine.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#restore_to_time ⇒ Time
The date and time to restore the cluster to.
Valid values: A time in Universal Coordinated Time (UTC) format.
Constraints:
-
Must be before the latest restorable time for the instance.
-
Must be specified if the
UseLatestRestorableTimeparameter is not provided. -
Cannot be specified if the
UseLatestRestorableTimeparameter istrue. -
Cannot be specified if the
RestoreTypeparameter iscopy-on-write.
Example: 2015-03-07T23:45:00Z
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#restore_type ⇒ String
The type of restore to be performed. You can specify one of the following values:
-
full-copy- The new DB cluster is restored as a full copy of the source DB cluster. -
copy-on-write- The new DB cluster is restored as a clone of the source DB cluster.
Constraints: You can't specify copy-on-write if the engine
version of the source DB cluster is earlier than 1.11.
If you don't specify a RestoreType value, then the new DB cluster
is restored as a full copy of the source DB cluster.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfiguration
Contains the scaling configuration of an Amazon DocumentDB Serverless cluster.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#source_db_cluster_identifier ⇒ String
The identifier of the source cluster from which to restore.
Constraints:
- Must match the identifier of an existing
DBCluster.
^
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The storage type to associate with the DB cluster.
For information on storage types for Amazon DocumentDB clusters, see Cluster storage configurations in the Amazon DocumentDB Developer Guide.
Valid values for storage type - standard | iopt1
Default value is standard
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the restored cluster.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#use_latest_restorable_time ⇒ Boolean
A value that is set to true to restore the cluster to the latest
restorable backup time, and false otherwise.
Default: false
Constraints: Cannot be specified if the RestoreToTime parameter is
provided.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security groups that the new cluster belongs to.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 |
# File 'lib/aws-sdk-docdb/types.rb', line 5903 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |