Class: Aws::DocDB::Waiters::DBInstanceDeleted

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-docdb/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ DBInstanceDeleted

Returns a new instance of DBInstanceDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


153
154
# File 'lib/aws-sdk-docdb/waiters.rb', line 153

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



208
209
210
# File 'lib/aws-sdk-docdb/waiters.rb', line 208

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DBInstanceMessage

Returns a response object which responds to the following methods:

Options Hash (params):

  • :db_instance_identifier (String)

    The user-provided instance identifier. If this parameter is specified, information from only the specific instance is returned. This parameter isn't case sensitive.

    Constraints:

    • If provided, must match the identifier of an existing DBInstance.

    ^

  • :filters (Array<Types::Filter>)

    A filter that specifies one or more instances to describe.

    Supported filters:

    • db-cluster-id - Accepts cluster identifiers and cluster Amazon Resource Names (ARNs). The results list includes only the information about the instances that are associated with the clusters that are identified by these ARNs.

    • db-instance-id - Accepts instance identifiers and instance ARNs. The results list includes only the information about the instances that are identified by these ARNs.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: Minimum 20, maximum 100.

  • :marker (String)

    An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:



203
# File 'lib/aws-sdk-docdb/waiters.rb', line 203

def wait: (