Method: Aws::DocDB::Types::DBInstanceStatusInfo#message
- Defined in:
- lib/aws-sdk-docdb/types.rb
#message ⇒ String
Details of the error if there is an error for the instance. If the instance is not in an error state, this value is blank.
2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/aws-sdk-docdb/types.rb', line 2251 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |