Class: Aws::DocDB::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DocDB::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-docdb/client.rb
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_tags_to_resource(params = {}) ⇒ Struct
Adds metadata tags to an Amazon DocumentDB resource.
-
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionResult
Applies a pending maintenance action to a resource (for example, to a DB instance).
-
#copy_db_cluster_parameter_group(params = {}) ⇒ Types::CopyDBClusterParameterGroupResult
Copies the specified DB cluster parameter group.
-
#copy_db_cluster_snapshot(params = {}) ⇒ Types::CopyDBClusterSnapshotResult
Copies a snapshot of a DB cluster.
-
#create_db_cluster(params = {}) ⇒ Types::CreateDBClusterResult
Creates a new Amazon DocumentDB DB cluster.
-
#create_db_cluster_parameter_group(params = {}) ⇒ Types::CreateDBClusterParameterGroupResult
Creates a new DB cluster parameter group.
-
#create_db_cluster_snapshot(params = {}) ⇒ Types::CreateDBClusterSnapshotResult
Creates a snapshot of a DB cluster.
-
#create_db_instance(params = {}) ⇒ Types::CreateDBInstanceResult
Creates a new DB instance.
-
#create_db_subnet_group(params = {}) ⇒ Types::CreateDBSubnetGroupResult
Creates a new DB subnet group.
-
#delete_db_cluster(params = {}) ⇒ Types::DeleteDBClusterResult
Deletes a previously provisioned DB cluster.
-
#delete_db_cluster_parameter_group(params = {}) ⇒ Struct
Deletes a specified DB cluster parameter group.
-
#delete_db_cluster_snapshot(params = {}) ⇒ Types::DeleteDBClusterSnapshotResult
Deletes a DB cluster snapshot.
-
#delete_db_instance(params = {}) ⇒ Types::DeleteDBInstanceResult
Deletes a previously provisioned DB instance.
-
#delete_db_subnet_group(params = {}) ⇒ Struct
Deletes a DB subnet group.
-
#describe_db_cluster_parameter_groups(params = {}) ⇒ Types::DBClusterParameterGroupsMessage
Returns a list of
DBClusterParameterGroupdescriptions. -
#describe_db_cluster_parameters(params = {}) ⇒ Types::DBClusterParameterGroupDetails
Returns the detailed parameter list for a particular DB cluster parameter group.
-
#describe_db_cluster_snapshot_attributes(params = {}) ⇒ Types::DescribeDBClusterSnapshotAttributesResult
Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot.
-
#describe_db_cluster_snapshots(params = {}) ⇒ Types::DBClusterSnapshotMessage
Returns information about DB cluster snapshots.
-
#describe_db_clusters(params = {}) ⇒ Types::DBClusterMessage
Returns information about provisioned Amazon DocumentDB DB clusters.
-
#describe_db_engine_versions(params = {}) ⇒ Types::DBEngineVersionMessage
Returns a list of the available DB engines.
-
#describe_db_instances(params = {}) ⇒ Types::DBInstanceMessage
Returns information about provisioned Amazon DocumentDB instances.
-
#describe_db_subnet_groups(params = {}) ⇒ Types::DBSubnetGroupMessage
Returns a list of
DBSubnetGroupdescriptions. -
#describe_engine_default_cluster_parameters(params = {}) ⇒ Types::DescribeEngineDefaultClusterParametersResult
Returns the default engine and system parameter information for the cluster database engine.
-
#describe_event_categories(params = {}) ⇒ Types::EventCategoriesMessage
Displays a list of categories for all event source types, or, if specified, for a specified source type.
-
#describe_events(params = {}) ⇒ Types::EventsMessage
Returns events related to DB instances, DB security groups, DB snapshots, and DB parameter groups for the past 14 days.
-
#describe_orderable_db_instance_options(params = {}) ⇒ Types::OrderableDBInstanceOptionsMessage
Returns a list of orderable DB instance options for the specified engine.
-
#describe_pending_maintenance_actions(params = {}) ⇒ Types::PendingMaintenanceActionsMessage
Returns a list of resources (for example, DB instances) that have at least one pending maintenance action.
-
#failover_db_cluster(params = {}) ⇒ Types::FailoverDBClusterResult
Forces a failover for a DB cluster.
-
#list_tags_for_resource(params = {}) ⇒ Types::TagListMessage
Lists all tags on an Amazon DocumentDB resource.
-
#modify_db_cluster(params = {}) ⇒ Types::ModifyDBClusterResult
Modifies a setting for an Amazon DocumentDB DB cluster.
-
#modify_db_cluster_parameter_group(params = {}) ⇒ Types::DBClusterParameterGroupNameMessage
Modifies the parameters of a DB cluster parameter group.
-
#modify_db_cluster_snapshot_attribute(params = {}) ⇒ Types::ModifyDBClusterSnapshotAttributeResult
Adds an attribute and values to, or removes an attribute and values from, a manual DB cluster snapshot.
-
#modify_db_instance(params = {}) ⇒ Types::ModifyDBInstanceResult
Modifies settings for a DB instance.
-
#modify_db_subnet_group(params = {}) ⇒ Types::ModifyDBSubnetGroupResult
Modifies an existing DB subnet group.
-
#reboot_db_instance(params = {}) ⇒ Types::RebootDBInstanceResult
You might need to reboot your DB instance, usually for maintenance reasons.
-
#remove_tags_from_resource(params = {}) ⇒ Struct
Removes metadata tags from an Amazon DocumentDB resource.
-
#reset_db_cluster_parameter_group(params = {}) ⇒ Types::DBClusterParameterGroupNameMessage
Modifies the parameters of a DB cluster parameter group to the default value.
-
#restore_db_cluster_from_snapshot(params = {}) ⇒ Types::RestoreDBClusterFromSnapshotResult
Creates a new DB cluster from a DB snapshot or DB cluster snapshot.
-
#restore_db_cluster_to_point_in_time(params = {}) ⇒ Types::RestoreDBClusterToPointInTimeResult
Restores a DB cluster to an arbitrary point in time.
-
#start_db_cluster(params = {}) ⇒ Types::StartDBClusterResult
Restarts the stopped cluster that is specified by
DBClusterIdentifier. -
#stop_db_cluster(params = {}) ⇒ Types::StopDBClusterResult
Stops the running cluster that is specified by
DBClusterIdentifier.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
251 252 253 |
# File 'lib/aws-sdk-docdb/client.rb', line 251 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4223 4224 4225 |
# File 'lib/aws-sdk-docdb/client.rb', line 4223 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4226 4227 4228 |
# File 'lib/aws-sdk-docdb/client.rb', line 4226 def errors_module Errors end |
Instance Method Details
#add_tags_to_resource(params = {}) ⇒ Struct
Adds metadata tags to an Amazon DocumentDB resource. You can use these tags with cost allocation reporting to track costs that are associated with Amazon DocumentDB resources. or in a Condition statement in an AWS Identity and Access Management (IAM) policy for Amazon DocumentDB.
287 288 289 290 |
# File 'lib/aws-sdk-docdb/client.rb', line 287 def (params = {}, = {}) req = build_request(:add_tags_to_resource, params) req.send_request() end |
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionResult
Applies a pending maintenance action to a resource (for example, to a DB instance).
345 346 347 348 |
# File 'lib/aws-sdk-docdb/client.rb', line 345 def apply_pending_maintenance_action(params = {}, = {}) req = build_request(:apply_pending_maintenance_action, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 |
# File 'lib/aws-sdk-docdb/client.rb', line 4086 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-docdb' context[:gem_version] = '1.10.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_db_cluster_parameter_group(params = {}) ⇒ Types::CopyDBClusterParameterGroupResult
Copies the specified DB cluster parameter group.
419 420 421 422 |
# File 'lib/aws-sdk-docdb/client.rb', line 419 def copy_db_cluster_parameter_group(params = {}, = {}) req = build_request(:copy_db_cluster_parameter_group, params) req.send_request() end |
#copy_db_cluster_snapshot(params = {}) ⇒ Types::CopyDBClusterSnapshotResult
Copies a snapshot of a DB cluster.
To copy a DB cluster snapshot from a shared manual DB cluster snapshot, SourceDBClusterSnapshotIdentifier must be the Amazon Resource Name (ARN) of the shared DB cluster snapshot.
To cancel the copy operation after it is in progress, delete the target DB cluster snapshot identified by TargetDBClusterSnapshotIdentifier while that DB cluster snapshot is in the copying status.
576 577 578 579 |
# File 'lib/aws-sdk-docdb/client.rb', line 576 def copy_db_cluster_snapshot(params = {}, = {}) req = build_request(:copy_db_cluster_snapshot, params) req.send_request() end |
#create_db_cluster(params = {}) ⇒ Types::CreateDBClusterResult
Creates a new Amazon DocumentDB DB cluster.
813 814 815 816 |
# File 'lib/aws-sdk-docdb/client.rb', line 813 def create_db_cluster(params = {}, = {}) req = build_request(:create_db_cluster, params) req.send_request() end |
#create_db_cluster_parameter_group(params = {}) ⇒ Types::CreateDBClusterParameterGroupResult
Creates a new DB cluster parameter group.
Parameters in a DB cluster parameter group apply to all of the instances in a DB cluster.
A DB cluster parameter group is initially created with the default parameters for the database engine used by instances in the DB cluster. To provide custom values for any of the parameters, you must modify the group after you create it. After you create a DB cluster parameter group, you must associate it with your DB cluster. For the new DB cluster parameter group and associated settings to take effect, you must then reboot the DB instances in the DB cluster without failover.
After you create a DB cluster parameter group, you should wait at least 5 minutes before creating your first DB cluster that uses that DB cluster parameter group as the default parameter group. This allows Amazon DocumentDB to fully complete the create action before the DB cluster parameter group is used as the default for a new DB cluster. This step is especially important for parameters that are critical when creating the default database for a DB cluster, such as the character set for the default database defined by the character_set_database parameter.
893 894 895 896 |
# File 'lib/aws-sdk-docdb/client.rb', line 893 def create_db_cluster_parameter_group(params = {}, = {}) req = build_request(:create_db_cluster_parameter_group, params) req.send_request() end |
#create_db_cluster_snapshot(params = {}) ⇒ Types::CreateDBClusterSnapshotResult
Creates a snapshot of a DB cluster.
971 972 973 974 |
# File 'lib/aws-sdk-docdb/client.rb', line 971 def create_db_cluster_snapshot(params = {}, = {}) req = build_request(:create_db_cluster_snapshot, params) req.send_request() end |
#create_db_instance(params = {}) ⇒ Types::CreateDBInstanceResult
Creates a new DB instance.
1136 1137 1138 1139 |
# File 'lib/aws-sdk-docdb/client.rb', line 1136 def create_db_instance(params = {}, = {}) req = build_request(:create_db_instance, params) req.send_request() end |
#create_db_subnet_group(params = {}) ⇒ Types::CreateDBSubnetGroupResult
Creates a new DB subnet group. DB subnet groups must contain at least one subnet in at least two Availability Zones in the AWS Region.
1196 1197 1198 1199 |
# File 'lib/aws-sdk-docdb/client.rb', line 1196 def create_db_subnet_group(params = {}, = {}) req = build_request(:create_db_subnet_group, params) req.send_request() end |
#delete_db_cluster(params = {}) ⇒ Types::DeleteDBClusterResult
Deletes a previously provisioned DB cluster. When you delete a DB cluster, all automated backups for that DB cluster are deleted and can’t be recovered. Manual DB cluster snapshots of the specified DB cluster are not deleted.
1304 1305 1306 1307 |
# File 'lib/aws-sdk-docdb/client.rb', line 1304 def delete_db_cluster(params = {}, = {}) req = build_request(:delete_db_cluster, params) req.send_request() end |
#delete_db_cluster_parameter_group(params = {}) ⇒ Struct
Deletes a specified DB cluster parameter group. The DB cluster parameter group to be deleted can’t be associated with any DB clusters.
1336 1337 1338 1339 |
# File 'lib/aws-sdk-docdb/client.rb', line 1336 def delete_db_cluster_parameter_group(params = {}, = {}) req = build_request(:delete_db_cluster_parameter_group, params) req.send_request() end |
#delete_db_cluster_snapshot(params = {}) ⇒ Types::DeleteDBClusterSnapshotResult
Deletes a DB cluster snapshot. If the snapshot is being copied, the copy operation is terminated.
<note markdown=“1”> The DB cluster snapshot must be in the available state to be deleted.
</note>
1390 1391 1392 1393 |
# File 'lib/aws-sdk-docdb/client.rb', line 1390 def delete_db_cluster_snapshot(params = {}, = {}) req = build_request(:delete_db_cluster_snapshot, params) req.send_request() end |
#delete_db_instance(params = {}) ⇒ Types::DeleteDBInstanceResult
Deletes a previously provisioned DB instance.
1482 1483 1484 1485 |
# File 'lib/aws-sdk-docdb/client.rb', line 1482 def delete_db_instance(params = {}, = {}) req = build_request(:delete_db_instance, params) req.send_request() end |
#delete_db_subnet_group(params = {}) ⇒ Struct
Deletes a DB subnet group.
<note markdown=“1”> The specified database subnet group must not be associated with any DB instances.
</note>
1520 1521 1522 1523 |
# File 'lib/aws-sdk-docdb/client.rb', line 1520 def delete_db_subnet_group(params = {}, = {}) req = build_request(:delete_db_subnet_group, params) req.send_request() end |
#describe_db_cluster_parameter_groups(params = {}) ⇒ Types::DBClusterParameterGroupsMessage
Returns a list of DBClusterParameterGroup descriptions. If a DBClusterParameterGroupName parameter is specified, the list contains only the description of the specified DB cluster parameter group.
1591 1592 1593 1594 |
# File 'lib/aws-sdk-docdb/client.rb', line 1591 def describe_db_cluster_parameter_groups(params = {}, = {}) req = build_request(:describe_db_cluster_parameter_groups, params) req.send_request() end |
#describe_db_cluster_parameters(params = {}) ⇒ Types::DBClusterParameterGroupDetails
Returns the detailed parameter list for a particular DB cluster parameter group.
1671 1672 1673 1674 |
# File 'lib/aws-sdk-docdb/client.rb', line 1671 def describe_db_cluster_parameters(params = {}, = {}) req = build_request(:describe_db_cluster_parameters, params) req.send_request() end |
#describe_db_cluster_snapshot_attributes(params = {}) ⇒ Types::DescribeDBClusterSnapshotAttributesResult
Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot.
When you share snapshots with other AWS accounts, DescribeDBClusterSnapshotAttributes returns the restore attribute and a list of IDs for the AWS accounts that are authorized to copy or restore the manual DB cluster snapshot. If all is included in the list of values for the restore attribute, then the manual DB cluster snapshot is public and can be copied or restored by all AWS accounts.
1712 1713 1714 1715 |
# File 'lib/aws-sdk-docdb/client.rb', line 1712 def describe_db_cluster_snapshot_attributes(params = {}, = {}) req = build_request(:describe_db_cluster_snapshot_attributes, params) req.send_request() end |
#describe_db_cluster_snapshots(params = {}) ⇒ Types::DBClusterSnapshotMessage
Returns information about DB cluster snapshots. This API operation supports pagination.
1851 1852 1853 1854 |
# File 'lib/aws-sdk-docdb/client.rb', line 1851 def describe_db_cluster_snapshots(params = {}, = {}) req = build_request(:describe_db_cluster_snapshots, params) req.send_request() end |
#describe_db_clusters(params = {}) ⇒ Types::DBClusterMessage
Returns information about provisioned Amazon DocumentDB DB clusters. This API operation supports pagination.
1963 1964 1965 1966 |
# File 'lib/aws-sdk-docdb/client.rb', line 1963 def describe_db_clusters(params = {}, = {}) req = build_request(:describe_db_clusters, params) req.send_request() end |
#describe_db_engine_versions(params = {}) ⇒ Types::DBEngineVersionMessage
Returns a list of the available DB engines.
2067 2068 2069 2070 |
# File 'lib/aws-sdk-docdb/client.rb', line 2067 def describe_db_engine_versions(params = {}, = {}) req = build_request(:describe_db_engine_versions, params) req.send_request() end |
#describe_db_instances(params = {}) ⇒ Types::DBInstanceMessage
Returns information about provisioned Amazon DocumentDB instances. This API supports pagination.
2201 2202 2203 2204 |
# File 'lib/aws-sdk-docdb/client.rb', line 2201 def describe_db_instances(params = {}, = {}) req = build_request(:describe_db_instances, params) req.send_request() end |
#describe_db_subnet_groups(params = {}) ⇒ Types::DBSubnetGroupMessage
Returns a list of DBSubnetGroup descriptions. If a DBSubnetGroupName is specified, the list will contain only the descriptions of the specified DBSubnetGroup.
2268 2269 2270 2271 |
# File 'lib/aws-sdk-docdb/client.rb', line 2268 def describe_db_subnet_groups(params = {}, = {}) req = build_request(:describe_db_subnet_groups, params) req.send_request() end |
#describe_engine_default_cluster_parameters(params = {}) ⇒ Types::DescribeEngineDefaultClusterParametersResult
Returns the default engine and system parameter information for the cluster database engine.
2336 2337 2338 2339 |
# File 'lib/aws-sdk-docdb/client.rb', line 2336 def describe_engine_default_cluster_parameters(params = {}, = {}) req = build_request(:describe_engine_default_cluster_parameters, params) req.send_request() end |
#describe_event_categories(params = {}) ⇒ Types::EventCategoriesMessage
Displays a list of categories for all event source types, or, if specified, for a specified source type.
2380 2381 2382 2383 |
# File 'lib/aws-sdk-docdb/client.rb', line 2380 def describe_event_categories(params = {}, = {}) req = build_request(:describe_event_categories, params) req.send_request() end |
#describe_events(params = {}) ⇒ Types::EventsMessage
Returns events related to DB instances, DB security groups, DB snapshots, and DB parameter groups for the past 14 days. You can obtain events specific to a particular DB instance, DB security group, DB snapshot, or DB parameter group by providing the name as a parameter. By default, the events of the past hour are returned.
2497 2498 2499 2500 |
# File 'lib/aws-sdk-docdb/client.rb', line 2497 def describe_events(params = {}, = {}) req = build_request(:describe_events, params) req.send_request() end |
#describe_orderable_db_instance_options(params = {}) ⇒ Types::OrderableDBInstanceOptionsMessage
Returns a list of orderable DB instance options for the specified engine.
2582 2583 2584 2585 |
# File 'lib/aws-sdk-docdb/client.rb', line 2582 def (params = {}, = {}) req = build_request(:describe_orderable_db_instance_options, params) req.send_request() end |
#describe_pending_maintenance_actions(params = {}) ⇒ Types::PendingMaintenanceActionsMessage
Returns a list of resources (for example, DB instances) that have at least one pending maintenance action.
2658 2659 2660 2661 |
# File 'lib/aws-sdk-docdb/client.rb', line 2658 def describe_pending_maintenance_actions(params = {}, = {}) req = build_request(:describe_pending_maintenance_actions, params) req.send_request() end |
#failover_db_cluster(params = {}) ⇒ Types::FailoverDBClusterResult
Forces a failover for a DB cluster.
A failover for a DB cluster promotes one of the Amazon DocumentDB replicas (read-only instances) in the DB cluster to be the primary instance (the cluster writer).
If the primary instance fails, Amazon DocumentDB automatically fails over to an Amazon DocumentDB replica, if one exists. You can force a failover when you want to simulate a failure of a primary instance for testing.
2747 2748 2749 2750 |
# File 'lib/aws-sdk-docdb/client.rb', line 2747 def failover_db_cluster(params = {}, = {}) req = build_request(:failover_db_cluster, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::TagListMessage
Lists all tags on an Amazon DocumentDB resource.
2787 2788 2789 2790 |
# File 'lib/aws-sdk-docdb/client.rb', line 2787 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#modify_db_cluster(params = {}) ⇒ Types::ModifyDBClusterResult
Modifies a setting for an Amazon DocumentDB DB cluster. You can change one or more database configuration parameters by specifying these parameters and the new values in the request.
2991 2992 2993 2994 |
# File 'lib/aws-sdk-docdb/client.rb', line 2991 def modify_db_cluster(params = {}, = {}) req = build_request(:modify_db_cluster, params) req.send_request() end |
#modify_db_cluster_parameter_group(params = {}) ⇒ Types::DBClusterParameterGroupNameMessage
Modifies the parameters of a DB cluster parameter group. To modify more than one parameter, submit a list of the following: ParameterName, ParameterValue, and ApplyMethod. A maximum of 20 parameters can be modified in a single request.
<note markdown=“1”> Changes to dynamic parameters are applied immediately. Changes to static parameters require a reboot or maintenance window before the change can take effect.
</note>
After you create a DB cluster parameter group, you should wait at least 5 minutes before creating your first DB cluster that uses that DB cluster parameter group as the default parameter group. This allows Amazon DocumentDB to fully complete the create action before the parameter group is used as the default for a new DB cluster. This step is especially important for parameters that are critical when creating the default database for a DB cluster, such as the character set for the default database defined by the character_set_database parameter.
3055 3056 3057 3058 |
# File 'lib/aws-sdk-docdb/client.rb', line 3055 def modify_db_cluster_parameter_group(params = {}, = {}) req = build_request(:modify_db_cluster_parameter_group, params) req.send_request() end |
#modify_db_cluster_snapshot_attribute(params = {}) ⇒ Types::ModifyDBClusterSnapshotAttributeResult
Adds an attribute and values to, or removes an attribute and values from, a manual DB cluster snapshot.
To share a manual DB cluster snapshot with other AWS accounts, specify restore as the AttributeName, and use the ValuesToAdd parameter to add a list of IDs of the AWS accounts that are authorized to restore the manual DB cluster snapshot. Use the value all to make the manual DB cluster snapshot public, which means that it can be copied or restored by all AWS accounts. Do not add the all value for any manual DB cluster snapshots that contain private information that you don’t want available to all AWS accounts. If a manual DB cluster snapshot is encrypted, it can be shared, but only by specifying a list of authorized AWS account IDs for the ValuesToAdd parameter. You can’t use all as a value for that parameter in this case.
3133 3134 3135 3136 |
# File 'lib/aws-sdk-docdb/client.rb', line 3133 def modify_db_cluster_snapshot_attribute(params = {}, = {}) req = build_request(:modify_db_cluster_snapshot_attribute, params) req.send_request() end |
#modify_db_instance(params = {}) ⇒ Types::ModifyDBInstanceResult
Modifies settings for a DB instance. You can change one or more database configuration parameters by specifying these parameters and the new values in the request.
3310 3311 3312 3313 |
# File 'lib/aws-sdk-docdb/client.rb', line 3310 def modify_db_instance(params = {}, = {}) req = build_request(:modify_db_instance, params) req.send_request() end |
#modify_db_subnet_group(params = {}) ⇒ Types::ModifyDBSubnetGroupResult
Modifies an existing DB subnet group. DB subnet groups must contain at least one subnet in at least two Availability Zones in the AWS Region.
3361 3362 3363 3364 |
# File 'lib/aws-sdk-docdb/client.rb', line 3361 def modify_db_subnet_group(params = {}, = {}) req = build_request(:modify_db_subnet_group, params) req.send_request() end |
#reboot_db_instance(params = {}) ⇒ Types::RebootDBInstanceResult
You might need to reboot your DB instance, usually for maintenance reasons. For example, if you make certain changes, or if you change the DB cluster parameter group that is associated with the DB instance, you must reboot the instance for the changes to take effect.
Rebooting a DB instance restarts the database engine service. Rebooting a DB instance results in a momentary outage, during which the DB instance status is set to rebooting.
3467 3468 3469 3470 |
# File 'lib/aws-sdk-docdb/client.rb', line 3467 def reboot_db_instance(params = {}, = {}) req = build_request(:reboot_db_instance, params) req.send_request() end |
#remove_tags_from_resource(params = {}) ⇒ Struct
Removes metadata tags from an Amazon DocumentDB resource.
3494 3495 3496 3497 |
# File 'lib/aws-sdk-docdb/client.rb', line 3494 def (params = {}, = {}) req = build_request(:remove_tags_from_resource, params) req.send_request() end |
#reset_db_cluster_parameter_group(params = {}) ⇒ Types::DBClusterParameterGroupNameMessage
Modifies the parameters of a DB cluster parameter group to the default value. To reset specific parameters, submit a list of the following: ParameterName and ApplyMethod. To reset the entire DB cluster parameter group, specify the DBClusterParameterGroupName and ResetAllParameters parameters.
When you reset the entire group, dynamic parameters are updated immediately and static parameters are set to pending-reboot to take effect on the next DB instance reboot.
3556 3557 3558 3559 |
# File 'lib/aws-sdk-docdb/client.rb', line 3556 def reset_db_cluster_parameter_group(params = {}, = {}) req = build_request(:reset_db_cluster_parameter_group, params) req.send_request() end |
#restore_db_cluster_from_snapshot(params = {}) ⇒ Types::RestoreDBClusterFromSnapshotResult
Creates a new DB cluster from a DB snapshot or DB cluster snapshot.
If a DB snapshot is specified, the target DB cluster is created from the source DB snapshot with a default configuration and default security group.
If a DB cluster snapshot is specified, the target DB cluster is created from the source DB cluster restore point with the same configuration as the original source DB cluster, except that the new DB cluster is created with the default security group.
3740 3741 3742 3743 |
# File 'lib/aws-sdk-docdb/client.rb', line 3740 def restore_db_cluster_from_snapshot(params = {}, = {}) req = build_request(:restore_db_cluster_from_snapshot, params) req.send_request() end |
#restore_db_cluster_to_point_in_time(params = {}) ⇒ Types::RestoreDBClusterToPointInTimeResult
Restores a DB cluster to an arbitrary point in time. Users can restore to any point in time before LatestRestorableTime for up to BackupRetentionPeriod days. The target DB cluster is created from the source DB cluster with the same configuration as the original DB cluster, except that the new DB cluster is created with the default DB security group.
3931 3932 3933 3934 |
# File 'lib/aws-sdk-docdb/client.rb', line 3931 def restore_db_cluster_to_point_in_time(params = {}, = {}) req = build_request(:restore_db_cluster_to_point_in_time, params) req.send_request() end |
#start_db_cluster(params = {}) ⇒ Types::StartDBClusterResult
Restarts the stopped cluster that is specified by DBClusterIdentifier. For more information, see [Stopping and Starting an Amazon DocumentDB Cluster].
[1]: docs.aws.amazon.com/documentdb/latest/developerguide/db-cluster-stop-start.html
4004 4005 4006 4007 |
# File 'lib/aws-sdk-docdb/client.rb', line 4004 def start_db_cluster(params = {}, = {}) req = build_request(:start_db_cluster, params) req.send_request() end |
#stop_db_cluster(params = {}) ⇒ Types::StopDBClusterResult
Stops the running cluster that is specified by DBClusterIdentifier. The cluster must be in the available state. For more information, see [Stopping and Starting an Amazon DocumentDB Cluster].
[1]: docs.aws.amazon.com/documentdb/latest/developerguide/db-cluster-stop-start.html
4077 4078 4079 4080 |
# File 'lib/aws-sdk-docdb/client.rb', line 4077 def stop_db_cluster(params = {}, = {}) req = build_request(:stop_db_cluster, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts | | ——————— | ———————— | ——– | ————- | | db_instance_available | #describe_db_instances | 30 | 60 | | db_instance_deleted | #describe_db_instances | 30 | 60 |
4188 4189 4190 4191 4192 |
# File 'lib/aws-sdk-docdb/client.rb', line 4188 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4196 4197 4198 |
# File 'lib/aws-sdk-docdb/client.rb', line 4196 def waiter_names waiters.keys end |