Class: Aws::DocDB::Types::DBClusterParameterGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBClusterParameterGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Represents the output of DBClusterParameterGroups.
Instance Attribute Summary collapse
-
#db_cluster_parameter_groups ⇒ Array<Types::DBClusterParameterGroup>
A list of DB cluster parameter groups.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
Instance Attribute Details
#db_cluster_parameter_groups ⇒ Array<Types::DBClusterParameterGroup>
A list of DB cluster parameter groups.
1259 1260 1261 1262 1263 |
# File 'lib/aws-sdk-docdb/types.rb', line 1259 class DBClusterParameterGroupsMessage < Struct.new( :marker, :db_cluster_parameter_groups) include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
1259 1260 1261 1262 1263 |
# File 'lib/aws-sdk-docdb/types.rb', line 1259 class DBClusterParameterGroupsMessage < Struct.new( :marker, :db_cluster_parameter_groups) include Aws::Structure end |