Class: Aws::DocDB::Types::DBClusterRole

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Describes an Identity and Access Management (IAM) role that is associated with a cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#role_arnString

The Amazon Resource Name (ARN) of the IAMrole that is associated with the DB cluster.



1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-docdb/types.rb', line 1620

class DBClusterRole < Struct.new(
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Describes the state of association between the IAMrole and the cluster. The Status property returns one of the following values:

  • ACTIVE - The IAMrole ARN is associated with the cluster and can be used to access other Amazon Web Services services on your behalf.

  • PENDING - The IAMrole ARN is being associated with the cluster.

  • INVALID - The IAMrole ARN is associated with the cluster, but the cluster cannot assume the IAMrole to access other Amazon Web Services services on your behalf.



1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-docdb/types.rb', line 1620

class DBClusterRole < Struct.new(
  :role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end