Class: Aws::DocDB::Types::DBClusterSnapshot
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBClusterSnapshot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Detailed information about a cluster snapshot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<String>
Provides the list of Amazon EC2 Availability Zones that instances in the cluster snapshot can be restored in.
-
#cluster_create_time ⇒ Time
Specifies the time when the cluster was created, in Universal Coordinated Time (UTC).
-
#db_cluster_identifier ⇒ String
Specifies the cluster identifier of the cluster that this cluster snapshot was created from.
-
#db_cluster_snapshot_arn ⇒ String
The Amazon Resource Name (ARN) for the cluster snapshot.
-
#db_cluster_snapshot_identifier ⇒ String
Specifies the identifier for the cluster snapshot.
-
#engine ⇒ String
Specifies the name of the database engine.
-
#engine_version ⇒ String
Provides the version of the database engine for this cluster snapshot.
-
#kms_key_id ⇒ String
If
StorageEncryptedistrue, the KMS key identifier for the encrypted cluster snapshot. -
#master_username ⇒ String
Provides the master user name for the cluster snapshot.
-
#percent_progress ⇒ Integer
Specifies the percentage of the estimated data that has been transferred.
-
#port ⇒ Integer
Specifies the port that the cluster was listening on at the time of the snapshot.
-
#snapshot_create_time ⇒ Time
Provides the time when the snapshot was taken, in UTC.
-
#snapshot_type ⇒ String
Provides the type of the cluster snapshot.
-
#source_db_cluster_snapshot_arn ⇒ String
If the cluster snapshot was copied from a source cluster snapshot, the ARN for the source cluster snapshot; otherwise, a null value.
-
#status ⇒ String
Specifies the status of this cluster snapshot.
-
#storage_encrypted ⇒ Boolean
Specifies whether the cluster snapshot is encrypted.
-
#storage_type ⇒ String
Storage type associated with your cluster snapshot.
-
#vpc_id ⇒ String
Provides the virtual private cloud (VPC) ID that is associated with the cluster snapshot.
Instance Attribute Details
#availability_zones ⇒ Array<String>
Provides the list of Amazon EC2 Availability Zones that instances in the cluster snapshot can be restored in.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#cluster_create_time ⇒ Time
Specifies the time when the cluster was created, in Universal Coordinated Time (UTC).
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
Specifies the cluster identifier of the cluster that this cluster snapshot was created from.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#db_cluster_snapshot_arn ⇒ String
The Amazon Resource Name (ARN) for the cluster snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#db_cluster_snapshot_identifier ⇒ String
Specifies the identifier for the cluster snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
Specifies the name of the database engine.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
Provides the version of the database engine for this cluster snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
If StorageEncrypted is true, the KMS key identifier for the
encrypted cluster snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#master_username ⇒ String
Provides the master user name for the cluster snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#percent_progress ⇒ Integer
Specifies the percentage of the estimated data that has been transferred.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
Specifies the port that the cluster was listening on at the time of the snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_create_time ⇒ Time
Provides the time when the snapshot was taken, in UTC.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_type ⇒ String
Provides the type of the cluster snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#source_db_cluster_snapshot_arn ⇒ String
If the cluster snapshot was copied from a source cluster snapshot, the ARN for the source cluster snapshot; otherwise, a null value.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Specifies the status of this cluster snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#storage_encrypted ⇒ Boolean
Specifies whether the cluster snapshot is encrypted.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
Storage type associated with your cluster snapshot
For information on storage types for Amazon DocumentDB clusters, see Cluster storage configurations in the Amazon DocumentDB Developer Guide.
Valid values for storage type - standard | iopt1
Default value is standard
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
Provides the virtual private cloud (VPC) ID that is associated with the cluster snapshot.
1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-docdb/types.rb', line 1869 class DBClusterSnapshot < Struct.new( :availability_zones, :db_cluster_snapshot_identifier, :db_cluster_identifier, :snapshot_create_time, :engine, :status, :port, :vpc_id, :cluster_create_time, :master_username, :engine_version, :snapshot_type, :percent_progress, :storage_encrypted, :kms_key_id, :db_cluster_snapshot_arn, :source_db_cluster_snapshot_arn, :storage_type) SENSITIVE = [] include Aws::Structure end |