Class: Aws::DocDB::Types::DBClusterSnapshotAttributesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBClusterSnapshotAttributesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Detailed information about the attributes that are associated with a DB cluster snapshot.
Instance Attribute Summary collapse
-
#db_cluster_snapshot_attributes ⇒ Array<Types::DBClusterSnapshotAttribute>
The list of attributes and values for the DB cluster snapshot.
-
#db_cluster_snapshot_identifier ⇒ String
The identifier of the DB cluster snapshot that the attributes apply to.
Instance Attribute Details
#db_cluster_snapshot_attributes ⇒ Array<Types::DBClusterSnapshotAttribute>
The list of attributes and values for the DB cluster snapshot.
1445 1446 1447 1448 1449 |
# File 'lib/aws-sdk-docdb/types.rb', line 1445 class DBClusterSnapshotAttributesResult < Struct.new( :db_cluster_snapshot_identifier, :db_cluster_snapshot_attributes) include Aws::Structure end |
#db_cluster_snapshot_identifier ⇒ String
The identifier of the DB cluster snapshot that the attributes apply to.
1445 1446 1447 1448 1449 |
# File 'lib/aws-sdk-docdb/types.rb', line 1445 class DBClusterSnapshotAttributesResult < Struct.new( :db_cluster_snapshot_identifier, :db_cluster_snapshot_attributes) include Aws::Structure end |