Class: Aws::DocDB::Types::DBEngineVersion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Detailed information about an engine version.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_engine_descriptionString

The description of the database engine.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#db_engine_version_descriptionString

The description of the database engine version.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#db_parameter_group_familyString

The name of the parameter group family for the database engine.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The name of the database engine.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The version number of the database engine.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#exportable_log_typesArray<String>

The types of logs that the database engine has available for export to Amazon CloudWatch Logs.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#supported_ca_certificate_identifiersArray<String>

A list of the supported CA certificate identifiers.

For more information, see [Updating Your Amazon DocumentDB TLS Certificates][1] and [ Encrypting Data in Transit][2] in the *Amazon DocumentDB Developer Guide*.

[1]: docs.aws.amazon.com/documentdb/latest/developerguide/ca_cert_rotation.html [2]: docs.aws.amazon.com/documentdb/latest/developerguide/security.encryption.ssl.html



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#supports_certificate_rotation_without_restartBoolean

Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#supports_log_exports_to_cloudwatch_logsBoolean

A value that indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end

#valid_upgrade_targetArray<Types::UpgradeTarget>

A list of engine versions that this database engine version can be upgraded to.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
# File 'lib/aws-sdk-docdb/types.rb', line 1971

class DBEngineVersion < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_description,
  :valid_upgrade_target,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supported_ca_certificate_identifiers,
  :supports_certificate_rotation_without_restart)
  SENSITIVE = []
  include Aws::Structure
end