Class: Aws::DocDB::Types::DBInstanceStatusInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::DBInstanceStatusInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Provides a list of status information for an instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Details of the error if there is an error for the instance.
-
#normal ⇒ Boolean
A Boolean value that is
trueif the instance is operating normally, orfalseif the instance is in an error state. -
#status ⇒ String
Status of the instance.
-
#status_type ⇒ String
This value is currently “‘read replication`.”.
Instance Attribute Details
#message ⇒ String
Details of the error if there is an error for the instance. If the instance is not in an error state, this value is blank.
2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/aws-sdk-docdb/types.rb', line 2251 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#normal ⇒ Boolean
A Boolean value that is true if the instance is operating normally, or false if the instance is in an error state.
2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/aws-sdk-docdb/types.rb', line 2251 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the instance. For a StatusType of read replica, the values can be replicating, error, stopped, or terminated.
2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/aws-sdk-docdb/types.rb', line 2251 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#status_type ⇒ String
This value is currently “‘read replication`.”
2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/aws-sdk-docdb/types.rb', line 2251 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |