Class: Aws::DocDB::Types::DescribeCertificatesMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_identifierString

The user-supplied certificate identifier. If this parameter is specified, information for only the specified certificate is returned. If this parameter is omitted, a list of up to MaxRecords certificates is returned. This parameter is not case sensitive.

Constraints

  • Must match an existing CertificateIdentifier.

^



2668
2669
2670
2671
2672
2673
2674
2675
# File 'lib/aws-sdk-docdb/types.rb', line 2668

class DescribeCertificatesMessage < Struct.new(
  :certificate_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter is not currently supported.



2668
2669
2670
2671
2672
2673
2674
2675
# File 'lib/aws-sdk-docdb/types.rb', line 2668

class DescribeCertificatesMessage < Struct.new(
  :certificate_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeCertificates request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



2668
2669
2670
2671
2672
2673
2674
2675
# File 'lib/aws-sdk-docdb/types.rb', line 2668

class DescribeCertificatesMessage < Struct.new(
  :certificate_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints:

  • Minimum: 20

  • Maximum: 100



2668
2669
2670
2671
2672
2673
2674
2675
# File 'lib/aws-sdk-docdb/types.rb', line 2668

class DescribeCertificatesMessage < Struct.new(
  :certificate_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end