Class: Aws::DocDB::Types::DescribeEventsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-docdb/types.rb

Overview

Represents the input to DescribeEvents.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durationInteger

The number of minutes to retrieve events for.

Default: 60



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end of the time interval for which to retrieve events, specified in ISO 8601 format.

Example: 2009-07-08T18:00Z



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#event_categoriesArray<String>

A list of event categories that trigger notifications for an event notification subscription.



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter is not currently supported.



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#source_identifierString

The identifier of the event source for which events are returned. If not specified, then all sources are included in the response.

Constraints:

  • If SourceIdentifier is provided, SourceType must also be provided.

  • If the source type is DBInstance, a DBInstanceIdentifier must be provided.

  • If the source type is DBSecurityGroup, a DBSecurityGroupName must be provided.

  • If the source type is DBParameterGroup, a DBParameterGroupName must be provided.

  • If the source type is DBSnapshot, a DBSnapshotIdentifier must be provided.

  • Cannot end with a hyphen or contain two consecutive hyphens.



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The event source to retrieve events for. If no value is specified, all events are returned.



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The beginning of the time interval to retrieve events for, specified in ISO 8601 format.

Example: 2009-07-08T18:00Z



3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
# File 'lib/aws-sdk-docdb/types.rb', line 3243

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end