Class: Aws::DocDB::Types::PendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::PendingModifiedValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
One or more modified settings for a DB instance. These modified settings have been requested, but haven’t been applied yet.
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
Contains the new
AllocatedStoragesize for the DB instance that will be applied or is currently being applied. -
#backup_retention_period ⇒ Integer
Specifies the pending number of days for which automated backups are retained.
-
#ca_certificate_identifier ⇒ String
Specifies the identifier of the certificate authority (CA) certificate for the DB instance.
-
#db_instance_class ⇒ String
Contains the new
DBInstanceClassfor the DB instance that will be applied or is currently being applied. -
#db_instance_identifier ⇒ String
Contains the new
DBInstanceIdentifierfor the DB instance that will be applied or is currently being applied. -
#db_subnet_group_name ⇒ String
The new DB subnet group for the DB instance.
-
#engine_version ⇒ String
Indicates the database engine version.
-
#iops ⇒ Integer
Specifies the new Provisioned IOPS value for the DB instance that will be applied or is currently being applied.
-
#license_model ⇒ String
The license model for the DB instance.
-
#master_user_password ⇒ String
Contains the pending or currently in-progress change of the master credentials for the DB instance.
-
#multi_az ⇒ Boolean
Indicates that the Single-AZ DB instance is to change to a Multi-AZ deployment.
-
#pending_cloudwatch_logs_exports ⇒ Types::PendingCloudwatchLogsExports
A list of the log types whose configuration is still pending.
-
#port ⇒ Integer
Specifies the pending port for the DB instance.
-
#storage_type ⇒ String
Specifies the storage type to be associated with the DB instance.
Instance Attribute Details
#allocated_storage ⇒ Integer
Contains the new AllocatedStorage size for the DB instance that will be applied or is currently being applied.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#backup_retention_period ⇒ Integer
Specifies the pending number of days for which automated backups are retained.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#ca_certificate_identifier ⇒ String
Specifies the identifier of the certificate authority (CA) certificate for the DB instance.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#db_instance_class ⇒ String
Contains the new DBInstanceClass for the DB instance that will be applied or is currently being applied.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#db_instance_identifier ⇒ String
Contains the new DBInstanceIdentifier for the DB instance that will be applied or is currently being applied.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#db_subnet_group_name ⇒ String
The new DB subnet group for the DB instance.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#engine_version ⇒ String
Indicates the database engine version.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#iops ⇒ Integer
Specifies the new Provisioned IOPS value for the DB instance that will be applied or is currently being applied.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#license_model ⇒ String
The license model for the DB instance.
Valid values: license-included, bring-your-own-license, general-public-license
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#master_user_password ⇒ String
Contains the pending or currently in-progress change of the master credentials for the DB instance.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#multi_az ⇒ Boolean
Indicates that the Single-AZ DB instance is to change to a Multi-AZ deployment.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#pending_cloudwatch_logs_exports ⇒ Types::PendingCloudwatchLogsExports
A list of the log types whose configuration is still pending. These log types are in the process of being activated or deactivated.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#port ⇒ Integer
Specifies the pending port for the DB instance.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |
#storage_type ⇒ String
Specifies the storage type to be associated with the DB instance.
3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/aws-sdk-docdb/types.rb', line 3981 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) include Aws::Structure end |