Class: Aws::DocDB::Types::RebootDBInstanceMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::RebootDBInstanceMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
Note:
When making an API call, you may pass RebootDBInstanceMessage data as a hash:
{
db_instance_identifier: "String", # required
force_failover: false,
}
Represents the input to RebootDBInstance.
Instance Attribute Summary collapse
-
#db_instance_identifier ⇒ String
The DB instance identifier.
-
#force_failover ⇒ Boolean
When
true, the reboot is conducted through a Multi-AZ failover.
Instance Attribute Details
#db_instance_identifier ⇒ String
The DB instance identifier. This parameter is stored as a lowercase string.
Constraints:
-
Must match the identifier of an existing
DBInstance.
^
4029 4030 4031 4032 4033 |
# File 'lib/aws-sdk-docdb/types.rb', line 4029 class RebootDBInstanceMessage < Struct.new( :db_instance_identifier, :force_failover) include Aws::Structure end |
#force_failover ⇒ Boolean
When true, the reboot is conducted through a Multi-AZ failover.
Constraint: You can’t specify true if the instance is not configured for Multi-AZ.
4029 4030 4031 4032 4033 |
# File 'lib/aws-sdk-docdb/types.rb', line 4029 class RebootDBInstanceMessage < Struct.new( :db_instance_identifier, :force_failover) include Aws::Structure end |