Class: Aws::DocDB::Types::RestoreDBClusterFromSnapshotMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::RestoreDBClusterFromSnapshotMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass RestoreDBClusterFromSnapshotMessage data as a hash:
{
availability_zones: ["String"],
db_cluster_identifier: "String", # required
snapshot_identifier: "String", # required
engine: "String", # required
engine_version: "String",
port: 1,
db_subnet_group_name: "String",
vpc_security_group_ids: ["String"],
tags: [
{
key: "String",
value: "String",
},
],
kms_key_id: "String",
enable_cloudwatch_logs_exports: ["String"],
deletion_protection: false,
}
Represents the input to RestoreDBClusterFromSnapshot.
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<String>
Provides the list of Amazon EC2 Availability Zones that instances in the restored DB cluster can be created in.
-
#db_cluster_identifier ⇒ String
The name of the DB cluster to create from the DB snapshot or DB cluster snapshot.
-
#db_subnet_group_name ⇒ String
The name of the DB subnet group to use for the new DB cluster.
-
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted.
-
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that must be enabled for exporting to Amazon CloudWatch Logs.
-
#engine ⇒ String
The database engine to use for the new DB cluster.
-
#engine_version ⇒ String
The version of the database engine to use for the new DB cluster.
-
#kms_key_id ⇒ String
The AWS KMS key identifier to use when restoring an encrypted DB cluster from a DB snapshot or DB cluster snapshot.
-
#port ⇒ Integer
The port number on which the new DB cluster accepts connections.
-
#snapshot_identifier ⇒ String
The identifier for the DB snapshot or DB cluster snapshot to restore from.
-
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the restored DB cluster.
-
#vpc_security_group_ids ⇒ Array<String>
A list of virtual private cloud (VPC) security groups that the new DB cluster will belong to.
Instance Attribute Details
#availability_zones ⇒ Array<String>
Provides the list of Amazon EC2 Availability Zones that instances in the restored DB cluster can be created in.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_cluster_identifier ⇒ String
The name of the DB cluster to create from the DB snapshot or DB cluster snapshot. This parameter isn’t case sensitive.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens.
-
The first character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
Example: my-snapshot-id
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_subnet_group_name ⇒ String
The name of the DB subnet group to use for the new DB cluster.
Constraints: If provided, must match the name of an existing DBSubnetGroup.
Example: mySubnetgroup
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted. If DeletionProtection is enabled, the cluster cannot be deleted unless it is modified and DeletionProtection is disabled. DeletionProtection protects clusters from being accidentally deleted.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that must be enabled for exporting to Amazon CloudWatch Logs.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#engine ⇒ String
The database engine to use for the new DB cluster.
Default: The same as source.
Constraint: Must be compatible with the engine of the source.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#engine_version ⇒ String
The version of the database engine to use for the new DB cluster.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#kms_key_id ⇒ String
The AWS KMS key identifier to use when restoring an encrypted DB cluster from a DB snapshot or DB cluster snapshot.
The AWS KMS key identifier is the Amazon Resource Name (ARN) for the AWS KMS encryption key. If you are restoring a DB cluster with the same AWS account that owns the AWS KMS encryption key used to encrypt the new DB cluster, then you can use the AWS KMS key alias instead of the ARN for the AWS KMS encryption key.
If you do not specify a value for the KmsKeyId parameter, then the following occurs:
-
If the DB snapshot or DB cluster snapshot in
SnapshotIdentifieris encrypted, then the restored DB cluster is encrypted using the AWS KMS key that was used to encrypt the DB snapshot or the DB cluster snapshot. -
If the DB snapshot or the DB cluster snapshot in
SnapshotIdentifieris not encrypted, then the restored DB cluster is not encrypted.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#port ⇒ Integer
The port number on which the new DB cluster accepts connections.
Constraints: Must be a value from 1150 to 65535.
Default: The same port as the original DB cluster.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#snapshot_identifier ⇒ String
The identifier for the DB snapshot or DB cluster snapshot to restore from.
You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot.
Constraints:
-
Must match the identifier of an existing snapshot.
^
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the restored DB cluster.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of virtual private cloud (VPC) security groups that the new DB cluster will belong to.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 |
# File 'lib/aws-sdk-docdb/types.rb', line 4279 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |