Class: Aws::DocDB::Types::RestoreDBClusterToPointInTimeMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DocDB::Types::RestoreDBClusterToPointInTimeMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-docdb/types.rb
Overview
When making an API call, you may pass RestoreDBClusterToPointInTimeMessage data as a hash:
{
db_cluster_identifier: "String", # required
source_db_cluster_identifier: "String", # required
restore_to_time: Time.now,
use_latest_restorable_time: false,
port: 1,
db_subnet_group_name: "String",
vpc_security_group_ids: ["String"],
tags: [
{
key: "String",
value: "String",
},
],
kms_key_id: "String",
enable_cloudwatch_logs_exports: ["String"],
deletion_protection: false,
}
Represents the input to RestoreDBClusterToPointInTime.
Instance Attribute Summary collapse
-
#db_cluster_identifier ⇒ String
The name of the new DB cluster to be created.
-
#db_subnet_group_name ⇒ String
The DB subnet group name to use for the new DB cluster.
-
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted.
-
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that must be enabled for exporting to Amazon CloudWatch Logs.
-
#kms_key_id ⇒ String
The AWS KMS key identifier to use when restoring an encrypted DB cluster from an encrypted DB cluster.
-
#port ⇒ Integer
The port number on which the new DB cluster accepts connections.
-
#restore_to_time ⇒ Time
The date and time to restore the DB cluster to.
-
#source_db_cluster_identifier ⇒ String
The identifier of the source DB cluster from which to restore.
-
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the restored DB cluster.
-
#use_latest_restorable_time ⇒ Boolean
A value that is set to
trueto restore the DB cluster to the latest restorable backup time, andfalseotherwise. -
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security groups that the new DB cluster belongs to.
Instance Attribute Details
#db_cluster_identifier ⇒ String
The name of the new DB cluster to be created.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens.
-
The first character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#db_subnet_group_name ⇒ String
The DB subnet group name to use for the new DB cluster.
Constraints: If provided, must match the name of an existing DBSubnetGroup.
Example: mySubnetgroup
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#deletion_protection ⇒ Boolean
Specifies whether this cluster can be deleted. If DeletionProtection is enabled, the cluster cannot be deleted unless it is modified and DeletionProtection is disabled. DeletionProtection protects clusters from being accidentally deleted.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that must be enabled for exporting to Amazon CloudWatch Logs.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#kms_key_id ⇒ String
The AWS KMS key identifier to use when restoring an encrypted DB cluster from an encrypted DB cluster.
The AWS KMS key identifier is the Amazon Resource Name (ARN) for the AWS KMS encryption key. If you are restoring a DB cluster with the same AWS account that owns the AWS KMS encryption key used to encrypt the new DB cluster, then you can use the AWS KMS key alias instead of the ARN for the AWS KMS encryption key.
You can restore to a new DB cluster and encrypt the new DB cluster with an AWS KMS key that is different from the AWS KMS key used to encrypt the source DB cluster. The new DB cluster is encrypted with the AWS KMS key identified by the KmsKeyId parameter.
If you do not specify a value for the KmsKeyId parameter, then the following occurs:
-
If the DB cluster is encrypted, then the restored DB cluster is encrypted using the AWS KMS key that was used to encrypt the source DB cluster.
-
If the DB cluster is not encrypted, then the restored DB cluster is not encrypted.
If DBClusterIdentifier refers to a DB cluster that is not encrypted, then the restore request is rejected.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#port ⇒ Integer
The port number on which the new DB cluster accepts connections.
Constraints: Must be a value from 1150 to 65535.
Default: The default port for the engine.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#restore_to_time ⇒ Time
The date and time to restore the DB cluster to.
Valid values: A time in Universal Coordinated Time (UTC) format.
Constraints:
-
Must be before the latest restorable time for the DB instance.
-
Must be specified if the
UseLatestRestorableTimeparameter is not provided. -
Cannot be specified if the
UseLatestRestorableTimeparameter istrue. -
Cannot be specified if the
RestoreTypeparameter iscopy-on-write.
Example: 2015-03-07T23:45:00Z
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#source_db_cluster_identifier ⇒ String
The identifier of the source DB cluster from which to restore.
Constraints:
-
Must match the identifier of an existing
DBCluster.
^
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the restored DB cluster.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#use_latest_restorable_time ⇒ Boolean
A value that is set to true to restore the DB cluster to the latest restorable backup time, and false otherwise.
Default: false
Constraints: Cannot be specified if the RestoreToTime parameter is provided.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security groups that the new DB cluster belongs to.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-docdb/types.rb', line 4452 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_cloudwatch_logs_exports, :deletion_protection) include Aws::Structure end |